"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.nationalities_resolvers.nationalities_v2 import resolve_by_nats

test_data_males = {
    "american television series": "مسلسلات تلفزيونية أمريكية",
    "non-american television series": "مسلسلات تلفزيونية غير أمريكية",
    "non american television series": "مسلسلات تلفزيونية غير أمريكية",
    "non yemeni television series": "مسلسلات تلفزيونية غير يمنية",
    "non-yemeni television series": "مسلسلات تلفزيونية غير يمنية",
    # males - en_is_nat_ar_is_mens
    "yemeni non profit publishers": "ناشرون غير ربحيون يمنيون",
    "yemeni non-profit publishers": "ناشرون غير ربحيون يمنيون",
    "yemeni government officials": "مسؤولون حكوميون يمنيون",
    "saudi non profit publishers": "ناشرون غير ربحيون سعوديون",
    "egyptian government officials": "مسؤولون حكوميون مصريون",
}

test_data_ar = {
    "yemeni music groups": "فرق موسيقى يمنية",
    "yemeni rock musical groups": "فرق موسيقى روك يمنية",
    "yemeni alternative rock groups": "فرق روك بديل يمنية",
    "yemeni death metal musical groups": "فرق موسيقى ديث ميتال يمنية",
    "yemeni electronic music groups": "فرق موسيقى إلكترونية يمنية",
    "yemeni hard rock musical groups": "فرق موسيقى هارد روك يمنية",
    "yemeni hardcore punk groups": "فرق هاردكور بانك يمنية",
    "yemeni indie rock musical groups": "فرق موسيقى إيندي روك يمنية",
    "yemeni new wave musical groups": "فرق موسيقى موجة جديدة يمنية",
    "yemeni experimental musical groups": "فرق موسيقى تجريبية يمنية",
    "yemeni punk music groups": "فرق موسيقى بانك يمنية",
    "yemeni glam metal musical groups": "فرق موسيقى جلام ميتال يمنية",
    "yemeni dance music groups": "فرق موسيقى الرقص يمنية",
    "yemeni pop musical groups": "فرق موسيقى بوب يمنية",
    "yemeni pop punk groups": "فرق بوب بانك يمنية",
    "yemeni gothic rock groups": "فرق غوثك روك يمنية",
    "yemeni classical music groups": "فرق موسيقى كلاسيكية يمنية",
    "yemeni blues rock musical groups": "فرق موسيقى بلوز روك يمنية",
    "yemeni synth-pop groups": "فرق سينثبوب يمنية",
    "yemeni ambient music groups": "فرق موسيقى الأمبينت يمنية",
    "yemeni electronic rock musical groups": "فرق موسيقى إليكترونيك روك يمنية",
    "yemeni house music groups": "فرق هاوس يمنية",
    "yemeni power metal musical groups": "فرق موسيقى باور ميتال يمنية",
    "yemeni progressive metal musical groups": "فرق موسيقى بروجريسف ميتال يمنية",
    "yemeni grunge groups": "فرق غرنج يمنية",
    "yemeni noise musical groups": "فرق موسيقى ضوضائية يمنية",
    "yemeni symphonic metal musical groups": "فرق موسيقى ميتال سيمفوني يمنية",
    "yemeni comedy musical groups": "فرق موسيقى كوميديا يمنية",
    "yemeni disco groups": "فرق ديسكو يمنية",
    "yemeni rhythm and blues musical groups": "فرق موسيقى ريذم أند بلوز يمنية",
    "yemeni r&b musical groups": "فرق موسيقى ريذم أند بلوز يمنية",
    "yemeni dance groups": "فرق رقص يمنية",
    "yemeni emo musical groups": "فرق موسيقى إيمو يمنية",
    "yemeni new-age music groups": "فرق موسيقى العصر الجديد يمنية",
    "yemeni nu metal musical groups": "فرق موسيقى نيو ميتال يمنية",
    "yemeni bluegrass music groups": "فرق بلوغراس يمنية",
    "yemeni alternative metal musical groups": "فرق موسيقى ميتال بديل يمنية",
    "yemeni soul musical groups": "فرق موسيقى السول يمنية",
    "yemeni folk groups": "فرق فولك يمنية",
    "yemeni country groups": "فرق كانتري يمنية",
    "yemeni industrial rock musical groups": "فرق موسيقى إندستريال روك يمنية",
    "yemeni post-grunge groups": "فرق بوست-غرنج يمنية",
    "yemeni celtic music groups": "فرق موسيقى كلتية يمنية",
    "yemeni celtic rock groups": "فرق روك سيلتي يمنية",
    "yemeni folk musical groups": "فرق موسيقى فولك يمنية",
    "yemeni grindcore musical groups": "فرق موسيقى قريندكور يمنية",
    "yemeni political music groups": "فرق موسيقى سياسية يمنية",
    "yemeni technical death metal musical groups": "فرق موسيقى ديث ميتال الفني يمنية",
    "yemeni romani musical groups": "فرق موسيقى غجرية يمنية",
    "yemeni children's musical groups": "فرق موسيقى أطفال يمنية",
    "yemeni indie folk groups": "فرق إندي فولك يمنية",
    "yemeni avant-garde metal musical groups": "فرق موسيقى ميتال أفانت جارد يمنية",
    "yemeni ska musical groups": "فرق موسيقى سكا يمنية",
    "yemeni symphonic black metal musical groups": "فرق موسيقى بلاك ميتال سمفوني يمنية",
    "yemeni post-punk groups": "فرق بوست بانك يمنية",
    "yemeni new wave groups": "فرق موجة جديدة يمنية",
    "yemeni blues groups": "فرق بلوز يمنية",
    "yemeni rap groups": "فرق راب يمنية",
    "yemeni grunge musical groups": "فرق موسيقى غرنج يمنية",
    "yemeni blues rock groups": "فرق بلوز روك يمنية",
    "yemeni eurodisco groups": "فرق يوروديسكو يمنية",
    "yemeni gospel music groups": "فرق غوسبل يمنية",
    "yemeni soul music groups": "فرق موسيقى السول يمنية",
    "yemeni fusion groups": "فرق فيوشن يمنية",
    "yemeni metal groups": "فرق ميتال يمنية",
    "yemeni a cappella groups": "فرق أكابيلا يمنية",
    "yemeni early music groups": "فرق موسيقى مبكرة يمنية",
    "yemeni dance musical groups": "فرق موسيقى رقص يمنية",
    "yemeni hip hop musical groups": "فرق موسيقى هيب هوب يمنية",
    "yemeni gospel musical groups": "فرق موسيقى غوسبل يمنية",
    "yemeni polka groups": "فرق بولكا يمنية",
    "yemeni rap metal musical groups": "فرق موسيقى راب ميتال يمنية",
    "yemeni swing musical groups": "فرق موسيقى سوينغ يمنية",
    "yemeni big beat groups": "فرق بيغ بيت يمنية",
    "yemeni post-punk musical groups": "فرق موسيقى بوست بانك يمنية",
    "yemeni britpop groups": "فرق بوب بريطاني يمنية",
    "yemeni experimental music groups": "فرق موسيقى تجريبية يمنية",
    "yemeni funk groups": "فرق فانك يمنية",
    "yemeni trance musical groups": "فرق موسيقى ترانس يمنية",
    "yemeni qawwali groups": "فرق قوالي يمنية",
    "yemeni latin music groups": "فرق موسيقى لاتينية يمنية",
    "yemeni traditional musical groups": "فرق موسيقى تقليدية يمنية",
    "yemeni a cappella musical groups": "فرق موسيقى أكابيلا يمنية",
    "yemeni house groups": "فرق الهاوس يمنية",
    "yemeni post-grunge musical groups": "فرق موسيقى بوست-غرنج يمنية",
    "yemeni classical musical groups": "فرق موسيقى كلاسيكية يمنية",
    "yemeni art punk groups": "فرق آرت بانك يمنية",
    "yemeni techno groups": "فرق تكنو يمنية",
    "yemeni baroque music groups": "فرق موسيقى باروكية يمنية",
    "yemeni bhangra (music) musical groups": "فرق موسيقى بانغرا يمنية",
    "yemeni cantopop musical groups": "فرق موسيقى كانتوبوب يمنية",
    "yemeni r&b groups": "فرق ريذم أند بلوز يمنية",
    "yemeni christian punk groups": "فرق كريستيان بانك يمنية",
    "yemeni contemporary folk music groups": "فرق موسيقى فلكلورية يمنية",
    "yemeni dancehall groups": "فرق دانسهول يمنية",
    "yemeni dance-pop groups": "فرق رقص البوب يمنية",
    "yemeni europop groups": "فرق يوروبوب يمنية",
    "yemeni flamenco groups": "فرق فلامنكو يمنية",
    "yemeni french hip hop groups": "فرق هيب هوب فرنسي يمنية",
    "yemeni gangsta rap groups": "فرق راب العصابات يمنية",
    "yemeni gothic music groups": "فرق موسيقى غوثك يمنية",
    "yemeni horrorcore groups": "فرق هورور كور يمنية",
    "yemeni indie music groups": "فرق موسيقى إندي يمنية",
    "yemeni klezmer groups": "فرق كليزمر يمنية",
    "yemeni mandopop musical groups": "فرق موسيقى ماندوبوب يمنية",
    "yemeni mariachi groups": "فرق مرياتي يمنية",
    "yemeni industrial groups": "فرق صناعية يمنية",
    "yemeni electronic musical groups": "فرق موسيقى إليكترونيك يمنية",
    "yemeni minimal music groups": "فرق موسيقى حد أدنى يمنية",
    "yemeni música popular brasileira musical groups": "فرق موسيقى شعبية برازيلية يمنية",
    "yemeni swing music groups": "فرق سوينغ يمنية",
    "yemeni peruvian cumbia musical groups": "فرق موسيقى كومبيا بيروفية يمنية",
    "yemeni opera groups": "فرق أوبرا يمنية",
    "yemeni pop-rap groups": "فرق بوب راب يمنية",
    "yemeni punk blues musical groups": "فرق موسيقى بانك بلوز يمنية",
    "yemeni rapcore groups": "فرق راب كور يمنية",
    "yemeni reggaeton groups": "فرق ريغيه تون يمنية",
    "yemeni romani groups": "فرق غجرية يمنية",
    "yemeni southern hip hop groups": "فرق هيب هوب جنوبي يمنية",
    "yemeni teen pop groups": "فرق بوب الشباب يمنية",
    "yemeni tejano music groups": "فرق موسيقى تيخانو يمنية",
    "yemeni west coast hip hop groups": "فرق هيب هوب الساحل الغربي يمنية",
    "christian hip hop groups": "فرق هيب هوب مسيحية",
    "Christian hip-hop groups": "فرق هيب هوب مسيحية",
    "christian ska groups": "فرق سكا مسيحية",
    "christian children's books": "كتب أطفال مسيحية",
    "christian children's magazines": "مجلات أطفال مسيحية",
    "christian illuminated manuscripts": "مخطوطات مذهبة مسيحية",
    "christian manuscripts": "مخطوطات مسيحية",
    "christian new religious movements": "حركات دينية جديدة مسيحية",
    "christian paintings": "لوحات مسيحية",
    "belgian children's books": "كتب أطفال بلجيكية",
    "jewish children's magazines": "مجلات أطفال يهودية",
    "american international schools": "مدارس دولية أمريكية",
    "bengali hindu festivals": "مهرجانات هندوسية بنغالية",
    "british international schools": "مدارس دولية بريطانية",
    "canadian documentaries": "وثائقيات كندية",
    "chinese cookbooks": "كتب طبخ صينية",
    "English tennis commentators": "معلقو كرة مضرب إنجليزية",
    "european political websites": "مواقع ويب سياسية أوروبية",
    "french comic": "قصص مصورة فرنسية",
    "greek organized crime": "جريمة منظمة يونانية",
    "greek paintings": "لوحات يونانية",
    "indonesian online encyclopedias": "موسوعات إنترنت إندونيسية",
    "iranian paintings": "لوحات إيرانية",
    "irish paintings": "لوحات أيرلندية",
    "israeli architecture awards": "جوائز عمارة إسرائيلية",
    "jewish ethnic groups": "مجموعات عرقية يهودية",
    "Jewish feminist organizations": "منظمات نسوية يهودية",
    "jewish illuminated manuscripts": "مخطوطات مذهبة يهودية",
    "jewish manuscripts": "مخطوطات يهودية",
    "jewish medical organizations": "منظمات طبية يهودية",
    "jewish military units and formations": "وحدات وتشكيلات عسكرية يهودية",
    "jewish new religious movements": "حركات دينية جديدة يهودية",
    "jewish political movements": "حركات سياسية يهودية",
    "jewish religious movements": "حركات دينية يهودية",
    "korean international schools": "مدارس دولية كورية",
    "polish biographical dictionaries": "قواميس سير ذاتية بولندية",
    "portuguese international schools": "مدارس دولية برتغالية",
    "serbian cultural organizations": "منظمات ثقافية صربية",
    "thai buddhist temples": "معابد بوذية تايلندية",
    "turkish cookbooks": "كتب طبخ تركية",
    "american christian metal musical groups": "فرق موسيقى ميتال مسيحي أمريكية",
    "american christian rock groups": "فرق روك مسيحي أمريكية",
    "arab christian communities": "مجتمعات مسيحية عربية",
    "australian christian metal musical groups": "فرق موسيقى ميتال مسيحي أسترالية",
    "australian christian rock groups": "فرق روك مسيحي أسترالية",
    "brazilian christian metal musical groups": "فرق موسيقى ميتال مسيحي برازيلية",
    "brazilian christian rock groups": "فرق روك مسيحي برازيلية",
    "british christian rock groups": "فرق روك مسيحي بريطانية",
    "canadian christian metal musical groups": "فرق موسيقى ميتال مسيحي كندية",
    "canadian christian rock groups": "فرق روك مسيحي كندية",
    "english christian rock groups": "فرق روك مسيحي إنجليزية",
    "finnish christian metal musical groups": "فرق موسيقى ميتال مسيحي فنلندية",
    "german christian metal musical groups": "فرق موسيقى ميتال مسيحي ألمانية",
    "norwegian christian metal musical groups": "فرق موسيقى ميتال مسيحي نرويجية",
    "palestinian christian communities": "مجتمعات مسيحية فلسطينية",
    "swedish christian metal musical groups": "فرق موسيقى ميتال مسيحي سويدية",
    "swiss christian metal musical groups": "فرق موسيقى ميتال مسيحي سويسرية",
    "christian alternative metal groups": "فرق ميتال بديل مسيحية",
    "christian bibliographies": "ببليوجرافيات مسيحية",
    "christian conferences": "مؤتمرات مسيحية",
    "christian contemporary r&b groups": "فرق آر أند بي معاصر مسيحية",
    "christian metal musical groups": "فرق موسيقى ميتال مسيحية",
    "christian music awards": "جوائز موسيقى مسيحية",
    "christian pop groups": "فرق بوب مسيحية",
    "christian rhythm and blues groups": "فرق ريذم أند بلوز مسيحية",
    "christian socialist organizations": "منظمات اشتراكية مسيحية",
    "american country music groups": "فرق كانتري أمريكية",
    "american doom metal musical groups": "فرق موسيقى دوم ميتال أمريكية",
    "american rock music groups": "فرق موسيقى الروك أمريكية",
    "slovak eurodance groups": "فرق يورودانس سلوفاكية",
    "swedish ska groups": "فرق سكا سويدية",
    "jewish folk rock groups": "فرق فولك روك يهودية",
    "japanese indie pop groups": "فرق إيندي بوب يابانية",
    "iranian indie rock groups": "فرق إيندي روك إيرانية",
    "chinese hip hop groups": "فرق هيب هوب صينية",
    "chinese hip-hop groups": "فرق هيب هوب صينية",
    "jewish hip hop groups": "فرق هيب هوب يهودية",
    "Jewish hip-hop groups": "فرق هيب هوب يهودية",
    "armenian world music groups": "فرق موسيقى العالم أرمينية",
    "australian black metal musical groups": "فرق موسيقى بلاك ميتال أسترالية",
    "australian electronic dance music groups": "فرق موسيقى الرقص الإلكترونية أسترالية",
    "australian musicals": "مسرحيات غنائية أسترالية",
    "australian world music groups": "فرق موسيقى العالم أسترالية",
    "azerbaijani heavy metal musical groups": "فرق موسيقى هيفي ميتال أذربيجانية",
    "british black metal musical groups": "فرق موسيقى بلاك ميتال بريطانية",
    "canadian contemporary r&b musical groups": "فرق موسيقى آر أند بي معاصر كندية",
    "czech rock music groups": "فرق موسيقى الروك تشيكية",
    "czech thrash metal musical groups": "فرق موسيقى ثراش ميتال تشيكية",
    "french gothic metal musical groups": "فرق موسيقى غوثيك ميتال فرنسية",
    "icelandic pop music groups": "فرق موسيقى بوب آيسلندية",
    "indian funk musical groups": "فرق موسيقى فانك هندية",
    "indonesian rock music groups": "فرق موسيقى الروك إندونيسية",
    "italian black metal musical groups": "فرق موسيقى بلاك ميتال إيطالية",
    "malagasy world music groups": "فرق موسيقى العالم مدغشقرية",
    "mauritian folk music groups": "فرق موسيقى تقليدية موريشيوسية",
    "mexican blues musical groups": "فرق موسيقى بلوز مكسيكية",
    "norwegian folk music groups": "فرق موسيقى تقليدية نرويجية",
    "salvadoran reggae musical groups": "فرق موسيقى ريغيه سلفادورية",
    "saudiarabian black metal musical groups": "فرق موسيقى بلاك ميتال سعودية",
    "serbian reggae musical groups": "فرق موسيقى ريغيه صربية",
    "slovenian rock music groups": "فرق موسيقى الروك سلوفينية",
    "sri lankan heavy metal musical groups": "فرق موسيقى هيفي ميتال سريلانكية",
    "Swedish heavy metal musical groups by genre": "فرق موسيقى هيفي ميتال سويدية حسب النوع الفني",
    "swedish heavy metal musical groups": "فرق موسيقى هيفي ميتال سويدية",
    "syrian rock music groups": "فرق موسيقى الروك سورية",
    "tajikistani rock music groups": "فرق موسيقى الروك طاجيكستانية",
    "Bahraini King's Cup": "كأس ملك البحرين",
    "Yemeni King's Cup": "كأس ملك اليمن",
    "French Grand Prix": "جائزة فرنسا الكبرى",
    "Italian Grand Prix": "جائزة إيطاليا الكبرى",
    "French Open": "فرنسا المفتوحة",
    "Australian Open": "أستراليا المفتوحة",
    "French Ladies Open": "فرنسا المفتوحة للسيدات",
    "Canadian Cup": "كأس كندا",
    "Egyptian Independence": "استقلال مصر",
    "Syrian Independence": "استقلال سوريا",
    "Canadian National University": "جامعة كندا الوطنية",
    "Egyptian National University": "جامعة مصر الوطنية",
    "Canadian National University Alumni": "خريجو جامعة كندا الوطنية",
    "Egyptian National University Alumni": "خريجو جامعة مصر الوطنية",
    "Japanese national women's motorsports racing team": "منتخب اليابان لسباق رياضة المحركات للسيدات",
    "French national women's motorsports racing team": "منتخب فرنسا لسباق رياضة المحركات للسيدات",
}

test_data_the_male = {
    # the_male - en_is_nat_ar_is_al_mens
    "Iraqi President Cup": "كأس الرئيس العراقي",
    "Egyptian President Cup": "كأس الرئيس المصري",
    "Iraqi Federation Cup": "كأس الاتحاد العراقي",
    "Saudi Federation Cup": "كأس الاتحاد السعودي",
    "Iraqi FA Cup": "كأس الاتحاد العراقي",
    "Egyptian FA Cup": "كأس الاتحاد المصري",
    "Iraqi Occupation": "الاحتلال العراقي",
    "American Occupation": "الاحتلال الأمريكي",
    "Iraqi Super Cup": "كأس السوبر العراقي",
    "Egyptian Super Cup": "كأس السوبر المصري",
    "Saudi Elite Cup": "كأس النخبة السعودي",
    "Iraqi Referendum": "الاستفتاء العراقي",
    "Syrian Referendum": "الاستفتاء السوري",
    "American Involvement": "التدخل الأمريكي",
    "French Involvement": "التدخل الفرنسي",
    "Egyptian Census": "التعداد المصري",
    "Iraqi Census": "التعداد العراقي",
    "Iraqi Professional Football League": "دوري كرة القدم العراقي للمحترفين",
    "Saudi Professional Football League": "دوري كرة القدم السعودي للمحترفين",
    "Iraqi Premier Football League": "الدوري العراقي الممتاز لكرة القدم",
    "Egyptian Premier Football League": "الدوري المصري الممتاز لكرة القدم",
    "Iraqi National Super League": "دوري السوبر العراقي",
    "Egyptian National Super League": "دوري السوبر المصري",
    "Iraqi Super League": "دوري السوبر العراقي",
    "Saudi Super League": "دوري السوبر السعودي",
    "Iraqi Premier League": "الدوري العراقي الممتاز",
    "Egyptian Premier League": "الدوري المصري الممتاز",
    "Iraqi Premier Division": "الدوري العراقي الممتاز",
    "Saudi Premier Division": "الدوري السعودي الممتاز",
    "Iraqi amateur football league": "الدوري العراقي لكرة القدم للهواة",
    "Egyptian amateur football league": "الدوري المصري لكرة القدم للهواة",
    "Iraqi football league": "الدوري العراقي لكرة القدم",
    "Saudi football league": "الدوري السعودي لكرة القدم",
    "Egyptian Population Census": "التعداد السكاني المصري",
    "Iraqi Population Census": "التعداد السكاني العراقي",
    "Egyptian population and housing census": "التعداد المصري للسكان والمساكن",
    "Iraqi population and housing census": "التعداد العراقي للسكان والمساكن",
    "Egyptian National Party": "الحزب الوطني المصري",
    "Iraqi National Party": "الحزب الوطني العراقي",
    "Egyptian Criminal Law": "القانون الجنائي المصري",
    "Iraqi Criminal Law": "القانون الجنائي العراقي",
    "Egyptian Family Law": "قانون الأسرة المصري",
    "Iraqi Family Law": "قانون الأسرة العراقي",
    "Egyptian Labour Law": "قانون العمل المصري",
    "Iraqi Labour Law": "قانون العمل العراقي",
    "Egyptian Abortion Law": "قانون الإجهاض المصري",
    "American Abortion Law": "قانون الإجهاض الأمريكي",
    "French Rugby Union Leagues": "اتحاد دوري الرجبي الفرنسي",
    "Australian Rugby Union Leagues": "اتحاد دوري الرجبي الأسترالي",
    "French Women's Rugby Union": "اتحاد الرجبي الفرنسي للنساء",
    "Australian Women's Rugby Union": "اتحاد الرجبي الأسترالي للنساء",
    "French Rugby Union": "اتحاد الرجبي الفرنسي",
    "Australian Rugby Union": "اتحاد الرجبي الأسترالي",
    "American Presidential Pardons": "العفو الرئاسي الأمريكي",
    "Egyptian Presidential Pardons": "العفو الرئاسي المصري",
    "American Pardons": "العفو الأمريكي",
    "Egyptian Pardons": "العفو المصري",
}

test_data_male = {
    # male - en_is_nat_ar_is_man
    "Egyptian descent": "أصل مصري",
    "Iraqi descent": "أصل عراقي",
    "American military occupations": "احتلال عسكري أمريكي",
    "Iraqi military occupations": "احتلال عسكري عراقي",
    "French integration": "تكامل فرنسي",
    "Egyptian integration": "تكامل مصري",
    "Japanese innovation": "ابتكار ياباني",
    "American innovation": "ابتكار أمريكي",
    "Italian design": "تصميم إيطالي",
    "French design": "تصميم فرنسي",
    "French contemporary art": "فن معاصر فرنسي",
    "American contemporary art": "فن معاصر أمريكي",
    "Italian art": "فن إيطالي",
    "French art": "فن فرنسي",
    "Italian cuisine": "مطبخ إيطالي",
    "French cuisine": "مطبخ فرنسي",
    "Japanese calendar": "تقويم ياباني",
    "Chinese calendar": "تقويم صيني",
    "American non fiction literature": "أدب غير خيالي أمريكي",
    "French non fiction literature": "أدب غير خيالي فرنسي",
    "British non-fiction literature": "أدب غير خيالي بريطاني",
    "American non-fiction literature": "أدب غير خيالي أمريكي",
    "Russian literature": "أدب روسي",
    "French literature": "أدب فرنسي",
    "Indian caste system": "نظام طبقي هندي",
    "Pakistani caste system": "نظام طبقي باكستاني",
    "American law": "قانون أمريكي",
    "French law": "قانون فرنسي",
    "French wine": "نبيذ فرنسي",
    "Italian wine": "نبيذ إيطالي",
    "Egyptian history": "تاريخ مصري",
    "Iraqi history": "تاريخ عراقي",
    "American nuclear history": "تاريخ نووي أمريكي",
    "French nuclear history": "تاريخ نووي فرنسي",
    "American military history": "تاريخ عسكري أمريكي",
    "French military history": "تاريخ عسكري فرنسي",
    "Palestinian diaspora": "شتات فلسطيني",
    "Syrian diaspora": "شتات سوري",
    "Indian traditions": "تراث هندي",
    "Chinese traditions": "تراث صيني",
    "Irish folklore": "فلكور أيرلندي",
    "Scottish folklore": "فلكور إسكتلندي",
}

test_data_female = {
    # "women's sports": "رياضات نسائية",
    "American women's sports": "رياضات نسائية أمريكية",
    # female - en_is_nat_ar_is_women
    "American airstrikes": "ضربات جوية أمريكية",
    "American autobiographies": "ترجمة ذاتية أمريكية",
    "American awards and decorations": "جوائز وأوسمة أمريكية",
    "American awards": "جوائز أمريكية",
    "American companies": "شركات أمريكية",
    "American crimes against humanity": "جرائم ضد الإنسانية أمريكية",
    "American crimes": "جرائم أمريكية",
    "American elections": "انتخابات أمريكية",
    "American music": "موسيقى أمريكية",
    "American newspapers": "صحف أمريكية",
    "American organizations": "منظمات أمريكية",
    "american television series": "مسلسلات تلفزيونية أمريكية",
    "American universities": "جامعات أمريكية",
    "American war crimes": "جرائم حرب أمريكية",
    "American wars": "حروب أمريكية",
    "British autobiographies": "ترجمة ذاتية بريطانية",
    "British newspapers": "صحف بريطانية",
    "British universities": "جامعات بريطانية",
    "French architecture": "عمارة فرنسية",
    "French awards and decorations": "جوائز وأوسمة فرنسية",
    "French awards": "جوائز فرنسية",
    "French culture": "ثقافة فرنسية",
    "French elections": "انتخابات فرنسية",
    "French music": "موسيقى فرنسية",
    "French organizations": "منظمات فرنسية",
    "French phonologies": "تصريفات صوتية فرنسية",
    "French wars": "حروب فرنسية",
    "German automotive": "سيارات ألمانية",
    "Greek archipelagoes": "أرخبيلات يونانية",
    "Greek mythology": "أساطير يونانية",
    "Indonesian archipelagoes": "أرخبيلات إندونيسية",
    "Iraqi crimes": "جرائم عراقية",
    "Israeli airstrikes": "ضربات جوية إسرائيلية",
    "Israeli crimes against humanity": "جرائم ضد الإنسانية إسرائيلية",
    "Israeli war crimes": "جرائم حرب إسرائيلية",
    "Japanese architecture": "عمارة يابانية",
    "Japanese automotive": "سيارات يابانية",
    "Japanese culture": "ثقافة يابانية",
    "non american television series": "مسلسلات تلفزيونية غير أمريكية",
    "non yemeni television series": "مسلسلات تلفزيونية غير يمنية",
    "non-american television series": "مسلسلات تلفزيونية غير أمريكية",
    "non-yemeni television series": "مسلسلات تلفزيونية غير يمنية",
    "Roman mythology": "أساطير رومانية",
}

test_data_the_female = {
    # the_female - en_is_nat_ar_is_al_women
    "British royal air force": "القوات الجوية الملكية البريطانية",
    "Saudi royal air force": "القوات الجوية الملكية السعودية",
    "American air force": "القوات الجوية الأمريكية",
    "French air force": "القوات الجوية الفرنسية",
    "British royal defence force": "قوات الدفاع الملكية البريطانية",
    "Saudi royal defence force": "قوات الدفاع الملكية السعودية",
    "British royal navy": "البحرية الملكية البريطانية",
    "Saudi royal navy": "البحرية الملكية السعودية",
    "American naval force": "البحرية الأمريكية",
    "French naval force": "البحرية الفرنسية",
    "American naval forces": "البحرية الأمريكية",
    "French naval forces": "البحرية الفرنسية",
    "American navy": "البحرية الأمريكية",
    "British airways accidents and incidents": "حوادث الخطوط الجوية البريطانية",
    "American airways accidents and incidents": "حوادث الخطوط الجوية الأمريكية",
    "British airways": "الخطوط الجوية البريطانية",
    "American airways": "الخطوط الجوية الأمريكية",
    "French youth games": "الألعاب الفرنسية الشبابية",
    "Egyptian youth games": "الألعاب المصرية الشبابية",
    "American financial crisis": "الأزمة المالية الأمريكية",
    "Greek financial crisis": "الأزمة المالية اليونانية",
    "Egyptian presidential crisis": "الأزمة الرئاسية المصرية",
    "American presidential crisis": "الأزمة الرئاسية الأمريكية",
    "Egyptian military academy": "الأكاديمية العسكرية المصرية",
    "American military academy": "الأكاديمية العسكرية الأمريكية",
    "Egyptian military college": "الكلية العسكرية المصرية",
    "American military college": "الكلية العسكرية الأمريكية",
    "Greek crisis": "الأزمة اليونانية",
    "American crisis": "الأزمة الأمريكية",
    "American energy crisis": "أزمة الطاقة الأمريكية",
    "European energy crisis": "أزمة الطاقة الأوروبية",
    "American constitutional crisis": "الأزمة الدستورية الأمريكية",
    "Egyptian constitutional crisis": "الأزمة الدستورية المصرية",
    "French games competitors": "منافسون في الألعاب الفرنسية",
    "Egyptian games competitors": "منافسون في الألعاب المصرية",
    "American television people": "شخصيات التلفزة الأمريكية",
    "British television people": "شخصيات التلفزة البريطانية",
    "American presidential primaries": "الانتخابات الرئاسية التمهيدية الأمريكية",
    "French presidential primaries": "الانتخابات الرئاسية التمهيدية الفرنسية",
    "Egyptian legislative election": "الانتخابات التشريعية المصرية",
    "French legislative election": "الانتخابات التشريعية الفرنسية",
    "British parliamentary election": "الانتخابات البرلمانية البريطانية",
    "Egyptian parliamentary election": "الانتخابات البرلمانية المصرية",
    "American general election": "الانتخابات العامة الأمريكية",
    "British general election": "الانتخابات العامة البريطانية",
    "French presidential election": "انتخابات الرئاسة الفرنسية",
    "American presidential election": "انتخابات الرئاسة الأمريكية",
}


@pytest.mark.parametrize("category, expected", test_data_males.items(), ids=test_data_males.keys())
@pytest.mark.fast
def test_resolve_males(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data_ar.items(), ids=test_data_ar.keys())
@pytest.mark.fast
def test_resolve_ar(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data_the_male.items(), ids=test_data_the_male.keys())
@pytest.mark.fast
def test_resolve_the_male(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data_male.items(), ids=test_data_male.keys())
@pytest.mark.fast
def test_resolve_male(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data_female.items(), ids=test_data_female.keys())
@pytest.mark.fast
def test_resolve_female(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data_the_female.items(), ids=test_data_the_female.keys())
@pytest.mark.fast
def test_resolve_the_female(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_resolve_males", test_data_males, resolve_by_nats),
    ("test_resolve_ar", test_data_ar, resolve_by_nats),
    ("test_resolve_the_male", test_data_the_male, resolve_by_nats),
    ("test_resolve_male", test_data_male, resolve_by_nats),
    ("test_resolve_female", test_data_female, resolve_by_nats),
    ("test_resolve_the_female", test_data_the_female, resolve_by_nats),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_resolvers.us_states import (
    normalize_state,
    resolve_us_states,
    us_states_new_keys,
)
from ArWikiCats.translations import US_STATES

test_data = {
    "{en} in the War of 1812": "{ar} في حرب 1812",
    "{en} democrats": "ديمقراطيون من ولاية {ar}",
    "{en} lawyers": "محامون من ولاية {ar}",
    "{en} state court judges": "قضاة محكمة ولاية {ar}",
    "{en} state courts": "محكمة ولاية {ar}",
    "{en} state senators": "أعضاء مجلس شيوخ ولاية {ar}",
}

all_test_data = {}

for en, ar in US_STATES.items():  # ~150 per state
    test_one = {x.format(en=en).lower(): normalize_state(v.format(ar=ar)) for x, v in us_states_new_keys.items()}
    all_test_data.update(test_one)
    if len(all_test_data) > 360:
        break

to_test = [
    ("test_resolve_us_states", all_test_data, resolve_us_states),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


@pytest.mark.parametrize("category, expected_key", all_test_data.items(), ids=all_test_data.keys())
@pytest.mark.slow
def test_resolve_us_states(category: str, expected_key: str) -> None:
    label2 = resolve_us_states(category)
    assert label2 == expected_key


Work_US_State_data = {
    "mississippi territory": "إقليم مسيسيبي",
    "indiana territory": "إقليم إنديانا",
    "pennsylvania politicians": "سياسيو بنسلفانيا",
    "louisiana territory": "إقليم لويزيانا",
    "illinois territory": "إقليم إلينوي",
    "michigan territory": "إقليم ميشيغان",
    "missouri territory": "إقليم ميزوري",
    "alabama territory": "إقليم ألاباما",
    "arkansas territory": "إقليم أركنساس",
    "florida territory": "إقليم فلوريدا",
    "maryland politicians": "سياسيو ماريلند",
    "massachusetts politicians": "سياسيو ماساتشوستس",
    "wisconsin territory": "إقليم ويسكونسن",
    "oregon territory": "إقليم أوريغن",
    "iowa territory": "إقليم آيوا",
    "new mexico territory": "إقليم نيومكسيكو",
    "utah territory": "إقليم يوتا",
    "washington territory": "إقليم واشنطن",
    "nebraska territory": "إقليم نبراسكا",
    "kansas territory": "إقليم كانساس",
    "nevada territory": "إقليم نيفادا",
    "colorado territory": "إقليم كولورادو",
    "montana territory": "إقليم مونتانا",
    "arizona territory": "إقليم أريزونا",
    "wyoming territory": "إقليم وايومنغ",
    "idaho territory": "إقليم أيداهو",
    "oklahoma territory": "إقليم أوكلاهوما",
    "connecticut general assembly": "جمعية كونيتيكت العامة",
    "georgia general assembly": "جمعية جورجيا العامة",
    "kentucky general assembly": "جمعية كنتاكي العامة",
    "new jersey legislature": "هيئة نيوجيرسي التشريعية",
    "new york state legislature": "هيئة ولاية نيويورك التشريعية",
    "north carolina general assembly": "جمعية كارولاينا الشمالية العامة",
    "pennsylvania general assembly": "جمعية بنسلفانيا العامة",
    "south carolina general assembly": "جمعية كارولاينا الجنوبية العامة",
    "virginia general assembly": "جمعية فرجينيا العامة",
    "virginia politicians": "سياسيو فرجينيا",
    "connecticut politicians": "سياسيو كونيتيكت",
    "new jersey politicians": "سياسيو نيوجيرسي",
    "new york (state) politicians": "سياسيو ولاية نيويورك",
    "delaware politicians": "سياسيو ديلاوير",
    "kentucky politicians": "سياسيو كنتاكي",
    "south carolina politicians": "سياسيو كارولاينا الجنوبية",
    "california ballot propositions": "اقتراحات اقتراع كاليفورنيا",
    "illinois ballot measures": "إجراءات اقتراع إلينوي",
    "oregon ballot measures": "إجراءات اقتراع أوريغن",
    "washington (state) ballot measures": "إجراءات اقتراع ولاية واشنطن",
    "colorado ballot measures": "إجراءات اقتراع كولورادو",
    "massachusetts ballot measures": "إجراءات اقتراع ماساتشوستس",
    "arizona politicians": "سياسيو أريزونا",
    "arkansas politicians": "سياسيو أركنساس",
    "arkansas state court judges": "قضاة محكمة ولاية أركنساس",
    "colorado politicians": "سياسيو كولورادو",
    "colorado state court judges": "قضاة محكمة ولاية كولورادو",
    "georgia (u.s. state) politicians": "سياسيو ولاية جورجيا",
    "alabama politicians": "سياسيو ألاباما",
    "georgia (u.s. state) state court judges": "قضاة محكمة ولاية جورجيا",
    "alabama state court judges": "قضاة محكمة ولاية ألاباما",
    "indiana politicians": "سياسيو إنديانا",
    "indiana state court judges": "قضاة محكمة ولاية إنديانا",
    "california politicians": "سياسيو كاليفورنيا",
    "california state court judges": "قضاة محكمة ولاية كاليفورنيا",
    "nebraska politicians": "سياسيو نبراسكا",
    "nebraska state court judges": "قضاة محكمة ولاية نبراسكا",
    "tennessee politicians": "سياسيو تينيسي",
    "tennessee state court judges": "قضاة محكمة ولاية تينيسي",
    "nevada politicians": "سياسيو نيفادا",
    "texas politicians": "سياسيو تكساس",
    "new hampshire politicians": "سياسيو نيوهامشير",
    "texas state court judges": "قضاة محكمة ولاية تكساس",
    "new hampshire state court judges": "قضاة محكمة ولاية نيوهامشير",
    "new jersey state court judges": "قضاة محكمة ولاية نيوجيرسي",
    "new mexico politicians": "سياسيو نيومكسيكو",
    "new york state court judges": "قضاة محكمة ولاية نيويورك",
    "louisiana politicians": "سياسيو لويزيانا",
    "louisiana state court judges": "قضاة محكمة ولاية لويزيانا",
    "maine politicians": "سياسيو مين",
    "maine state court judges": "قضاة محكمة ولاية مين",
    "iowa politicians": "سياسيو آيوا",
    "iowa state court judges": "قضاة محكمة ولاية آيوا",
    "utah politicians": "سياسيو يوتا",
    "delaware state court judges": "قضاة محكمة ولاية ديلاوير",
    "vermont politicians": "سياسيو فيرمونت",
    "vermont state court judges": "قضاة محكمة ولاية فيرمونت",
    "south carolina state court judges": "قضاة محكمة ولاية كارولاينا الجنوبية",
    "south dakota politicians": "سياسيو داكوتا الجنوبية",
    "virginia state court judges": "قضاة محكمة ولاية فرجينيا",
    "massachusetts state court judges": "قضاة محكمة ولاية ماساتشوستس",
    "washington (state) politicians": "سياسيو ولاية واشنطن",
}


@pytest.mark.parametrize("category, expected_key", Work_US_State_data.items(), ids=Work_US_State_data.keys())
@pytest.mark.slow
def test_Work_US_State_data(category: str, expected_key: str) -> None:
    label = resolve_us_states(category)
    assert label == expected_key


fast_data = {
    "north carolina politicians": "سياسيو كارولاينا الشمالية",
    "north carolina state court judges": "قضاة محكمة ولاية كارولاينا الشمالية",
    "north dakota politicians": "سياسيو داكوتا الشمالية",
    "west virginia politicians": "سياسيو فرجينيا الغربية",
    "west virginia state court judges": "قضاة محكمة ولاية فرجينيا الغربية",
    "wisconsin politicians": "سياسيو ويسكونسن",
    "wisconsin state court judges": "قضاة محكمة ولاية ويسكونسن",
    "rhode island politicians": "سياسيو رود آيلاند",
    "idaho politicians": "سياسيو أيداهو",
    "illinois politicians": "سياسيو إلينوي",
    "illinois state court judges": "قضاة محكمة ولاية إلينوي",
    "ohio politicians": "سياسيو أوهايو",
    "ohio state court judges": "قضاة محكمة ولاية أوهايو",
    "oregon politicians": "سياسيو أوريغن",
    "florida politicians": "سياسيو فلوريدا",
    "alabama legislature": "هيئة ألاباما التشريعية",
    "arkansas general assembly": "جمعية أركنساس العامة",
    "california state legislature": "هيئة ولاية كاليفورنيا التشريعية",
    "colorado general assembly": "جمعية كولورادو العامة",
    "delaware general assembly": "جمعية ديلاوير العامة",
    "florida legislature": "هيئة فلوريدا التشريعية",
    "pennsylvania state court judges": "قضاة محكمة ولاية بنسلفانيا",
    "illinois general assembly": "جمعية إلينوي العامة",
    "indiana general assembly": "جمعية إنديانا العامة",
    "iowa general assembly": "جمعية آيوا العامة",
    "kansas legislature": "هيئة كانساس التشريعية",
    "wyoming politicians": "سياسيو وايومنغ",
    "louisiana state legislature": "هيئة ولاية لويزيانا التشريعية",
    "maine legislature": "هيئة مين التشريعية",
    "michigan legislature": "هيئة ميشيغان التشريعية",
    "minnesota legislature": "هيئة منيسوتا التشريعية",
    "kansas politicians": "سياسيو كانساس",
    "mississippi legislature": "هيئة مسيسيبي التشريعية",
    "kentucky state court judges": "قضاة محكمة ولاية كنتاكي",
    "missouri general assembly": "جمعية ميزوري العامة",
    "nebraska legislature": "هيئة نبراسكا التشريعية",
    "nevada legislature": "هيئة نيفادا التشريعية",
    "north dakota legislative assembly": "هيئة داكوتا الشمالية التشريعية",
    "ohio general assembly": "جمعية أوهايو العامة",
    "oregon legislative assembly": "هيئة أوريغن التشريعية",
    "rhode island general assembly": "جمعية رود آيلاند العامة",
    "south dakota legislature": "هيئة داكوتا الجنوبية التشريعية",
    "tennessee general assembly": "جمعية تينيسي العامة",
    "texas legislature": "هيئة تكساس التشريعية",
    "vermont general assembly": "جمعية فيرمونت العامة",
    "washington state legislature": "هيئة ولاية واشنطن التشريعية",
    "west virginia legislature": "هيئة فرجينيا الغربية التشريعية",
    "wisconsin legislature": "هيئة ويسكونسن التشريعية",
    "michigan politicians": "سياسيو ميشيغان",
    "michigan state court judges": "قضاة محكمة ولاية ميشيغان",
    "minnesota politicians": "سياسيو منيسوتا",
    "minnesota state court judges": "قضاة محكمة ولاية منيسوتا",
    "mississippi politicians": "سياسيو مسيسيبي",
    "mississippi state court judges": "قضاة محكمة ولاية مسيسيبي",
    "missouri politicians": "سياسيو ميزوري",
    "missouri state court judges": "قضاة محكمة ولاية ميزوري",
    "montana politicians": "سياسيو مونتانا",
    "maine ballot measures": "إجراءات اقتراع مين",
    "new jersey ballot measures": "إجراءات اقتراع نيوجيرسي",
    "missouri ballot measures": "إجراءات اقتراع ميزوري",
    "texas law": "قانون تكساس",
    "alaska politicians": "سياسيو ألاسكا",
    "hawaii politicians": "سياسيو هاواي",
    "connecticut state court judges": "قضاة محكمة ولاية كونيتيكت",
    "south dakota ballot measures": "إجراءات اقتراع داكوتا الجنوبية",
    "oklahoma politicians": "سياسيو أوكلاهوما",
    "alaska legislature": "هيئة ألاسكا التشريعية",
    "arizona state legislature": "هيئة ولاية أريزونا التشريعية",
    "hawaii state legislature": "هيئة ولاية هاواي التشريعية",
    "idaho legislature": "هيئة أيداهو التشريعية",
    "montana legislature": "هيئة مونتانا التشريعية",
    "new mexico legislature": "هيئة نيومكسيكو التشريعية",
    "oklahoma house-of-representatives": "مجلس نواب ولاية أوكلاهوما",
    "oklahoma legislature": "هيئة أوكلاهوما التشريعية",
    "utah legislature": "هيئة يوتا التشريعية",
    "wyoming legislature": "هيئة وايومنغ التشريعية",
    "maryland state court judges": "قضاة محكمة ولاية ماريلند",
}


@pytest.mark.parametrize("category, expected_key", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_fast_data(category: str, expected_key: str) -> None:
    label = resolve_us_states(category)
    assert label == expected_key



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.countries_names_resolvers.us_states import _STATE_SUFFIX_TEMPLATES_BASE, normalize_state
from ArWikiCats.translations import US_STATES

test_data_keys = {
    # "{en} republicans": "أعضاء الحزب الجمهوري في {ar}",
    "{en} counties": "مقاطعات {ar}",
    "{en} democratic-republicans": "أعضاء الحزب الديمقراطي الجمهوري في {ar}",
    "{en} elections by decade": "انتخابات {ar} حسب العقد",
    "{en} elections by year": "انتخابات {ar} حسب السنة",
    "{en} elections": "انتخابات {ar}",
    "{en} federalists": "أعضاء الحزب الفيدرالي الأمريكي في {ar}",
    "{en} greenbacks": "أعضاء حزب الدولار الأمريكي في {ar}",
    "{en} greens": "أعضاء حزب الخضر في {ar}",
    "{en} in fiction by city": "{ar} في الخيال حسب المدينة",
    "{en} in fiction": "{ar} في الخيال",
    "{en} in the american civil war": "{ar} في الحرب الأهلية الأمريكية",
    "{en} in the american revolution": "{ar} في الثورة الأمريكية",
    "{en} independents": "أعضاء في {ar}",
    "{en} know nothings": "أعضاء حزب لا أدري في {ar}",
    "{en} law-related lists": "قوائم متعلقة بقانون {ar}",
    "{en} navigational boxes": "صناديق تصفح {ar}",
    "{en} politicians by century": "سياسيو {ar} حسب القرن",
    "{en} politicians by party": "سياسيو {ar} حسب الحزب",
    "{en} politicians by populated place": "سياسيو {ar} حسب المكان المأهول",
    "{en} politics-related lists": "قوائم متعلقة بسياسة {ar}",
    "{en} socialists": "أعضاء الحزب الاشتراكي في {ar}",
    "{en} templates": "قوالب {ar}",
    "{en} unionists": "أعضاء الحزب الوحدوي في {ar}",
    "{en} whigs": "أعضاء حزب اليمين في {ar}",
    "{en}-related lists": "قوائم متعلقة ب{ar}",
}

test_data_keys.update(_STATE_SUFFIX_TEMPLATES_BASE)
if "{en} republicans" in test_data_keys:
    del test_data_keys["{en} republicans"]

all_test_data = {}

data_1 = {
    "iowa": {},
    "montana": {},
    "georgia (u.s. state)": {},
    "nebraska": {},
    "wisconsin": {},
    "new mexico": {},
    "arizona": {},
}

for en in data_1.keys():
    if US_STATES.get(en):
        ar = US_STATES.get(en)
        test_one = {f"{x.format(en=en)}": f"{normalize_state(v.format(ar=ar))}" for x, v in test_data_keys.items()}
        data_1[en] = test_one
        all_test_data.update(test_one)


to_test = [
    # (f"test_us_counties_{x}", v) for x, v in data_1.items()
    ("test_us_counties_iowa", data_1["iowa"])
]

to_test.append(("test_all_test_data", all_test_data))


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


@pytest.mark.parametrize("input_text,expected", all_test_data.items(), ids=all_test_data.keys())
@pytest.mark.slow
def test_all_data(input_text: str, expected: str) -> None:
    result = resolve_label_ar(input_text)
    assert result == expected


empty_data = {
    "Georgia (U.S. state) government navigational boxes": "صناديق تصفح حكومة ولاية جورجيا",
    "Georgia (U.S. state) National Republicans": "أعضاء الحزب الجمهوري الوطني في ولاية جورجيا",
    "Georgia (U.S. state) Attorney General elections": "",
    "Georgia (U.S. state) case law": "",
    "Georgia (U.S. state) city council members": "",
    "Georgia (U.S. state) city user templates": "",
    "Georgia (U.S. state) college and university user templates": "",
    "Georgia (U.S. state) commissioners of agriculture": "",
    "Georgia (U.S. state) Constitutional Unionists": "",
    "Georgia (U.S. state) county navigational boxes": "",
    "Georgia (U.S. state) culture by city": "",
    "Georgia (U.S. state) education navigational boxes": "",
    "Georgia (U.S. state) education-related lists": "",
    "Georgia (U.S. state) election templates": "",
    "Georgia (U.S. state) geography-related lists": "",
    "Georgia (U.S. state) high school athletic conference navigational boxes": "",
    "Georgia (U.S. state) history-related lists": "",
    "Georgia (U.S. state) judicial elections": "",
    "Georgia (U.S. state) labor commissioners": "",
    "Georgia (U.S. state) legislative districts": "",
    "Georgia (U.S. state) legislative sessions": "",
    "Georgia (U.S. state) Libertarians": "",
    "Georgia (U.S. state) lieutenant gubernatorial elections": "",
    "Georgia (U.S. state) location map modules": "",
    "Georgia (U.S. state) maps": "",
    "Georgia (U.S. state) mass media navigational boxes": "",
    "Georgia (U.S. state) militia": "",
    "Georgia (U.S. state) militiamen in the American Revolution": "",
    "Georgia (U.S. state) Oppositionists": "",
    "Georgia (U.S. state) placenames of Native American origin": "",
    "Georgia (U.S. state) Populists": "",
    "Georgia (U.S. state) portal": "",
    "Georgia (U.S. state) postmasters": "",
    "Georgia (U.S. state) presidential primaries": "",
    "Georgia (U.S. state) Progressives (1912)": "",
    "Georgia (U.S. state) Prohibitionists": "",
    "Georgia (U.S. state) radio market navigational boxes": "",
    "Georgia (U.S. state) railroads": "",
    "Georgia (U.S. state) Sea Islands": "",
    "Georgia (U.S. state) shopping mall templates": "",
    "Georgia (U.S. state) society": "",
    "Georgia (U.S. state) special elections": "",
    "Georgia (U.S. state) sports-related lists": "",
    "Georgia (U.S. state) state constitutional officer elections": "",
    "Georgia (U.S. state) state forests": "",
    "Georgia (U.S. state) statutes": "",
    "Georgia (U.S. state) television station user templates": "",
    "Georgia (U.S. state) transportation-related lists": "",
    "Georgia (U. S. state) universities and colleges leaders navigational boxes": "",
    "Georgia (U.S. state) universities and colleges navigational boxes": "",
    "Georgia (U.S. state) user categories": "",
    "Georgia (U.S. state) user templates": "",
    "Georgia (U.S. state) Wikipedians": "",
    "Georgia (U.S. state) wine": "",
}


@pytest.mark.dump
def test_us_counties_empty() -> None:
    expected, diff_result = one_dump_test(empty_data, resolve_label_ar)

    dump_diff(diff_result, "test_us_counties_empty")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(empty_data):,}"



#


def get_relation_word_new(category: str, data: dict[str, str]) -> tuple[str, str]:
    """Find the first relation token present in ``category`` using comprehension."""
    # Find the first matching separator key in the category
    matched_separator = next((key for key in data if f" {key} " in category), None)
    # ---
    if matched_separator:
        separator_name = data[matched_separator]
        separator = f" {matched_separator} "
        return separator, separator_name
    # ---
    return "", ""


def get_relation_word(category: str, data: dict[str, str]) -> tuple[str, str]:
    """Find a relation token by iterating the provided mapping order."""
    for separator, separator_name in data.items():
        separator = f" {separator} "
        # if Keep_Work and separator in category:
        if separator in category:
            return separator, separator_name
    # ---
    return "", ""


__all__ = [
    "get_relation_word_new",
    "get_relation_word",
]



# tests/relations/test_new_relations_resolvers_male.py
from __future__ import annotations

import pytest

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

males_data = {}


@pytest.mark.parametrize("category, expected", males_data.items(), ids=males_data.keys())
@pytest.mark.fast
def test_males_data(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.unit
def test_zanzibari_anguillan_conflict_from_nat_men() -> None:
    """Male 'conflict' using Nat_men demonyms."""
    value = "zanzibari-anguillan conflict"
    result = new_relations_resolvers(value)
    # زنجباري + أنغويلاني
    assert result == "الصراع الأنغويلاني الزنجباري"


@pytest.mark.unit
def test_prussian_afghan_conflict_video_games() -> None:
    """Male 'conflict video games' using Nat_men."""
    value = "prussian-afghan conflict video games"
    result = new_relations_resolvers(value)
    # بروسي + أفغاني
    assert result == "ألعاب فيديو الصراع الأفغاني البروسي"


@pytest.mark.unit
def test_football_rivalry_uses_correct_male_prefix_and_suffix() -> None:
    """Male 'football rivalry' formatting."""
    value = "zanzibari-anguillan football rivalry"
    result = new_relations_resolvers(value)
    assert result == "التنافس الأنغويلاني الزنجباري في كرة القدم"


@pytest.mark.unit
def test_male_branch_with_en_dash() -> None:
    """Male 'conflict' using en dash separator."""
    value = "zanzibari–anguillan conflict"
    result = new_relations_resolvers(value)
    assert result == "الصراع الأنغويلاني الزنجباري"


@pytest.mark.unit
def test_unknown_demonym_in_male_branch_returns_empty() -> None:
    """Unknown demonym in Nat_men should produce empty result."""
    value = "unknownland-anguillan conflict"
    result = new_relations_resolvers(value)
    assert result == ""


@pytest.mark.unit
def test_male_suffix_without_hyphen_returns_empty() -> None:
    """No hyphen-like separator means the function cannot split the pair."""
    value = "zanzibari--anguillan conflict"
    result = new_relations_resolvers(value)
    assert result == ""



#!/usr/bin/python3
"""
# from .india_2 import SECONDARY_REGION_TRANSLATIONS

"""

from ...helps import len_print
from ..utils.json_dir import open_json_file


def _load_india_region_translations() -> dict[str, str]:
    index_labels: dict[str, str] = {}

    india_district_labels = open_json_file("geography/India_dd.json") or {}

    for district_name, district_label in india_district_labels.items():
        normalized_name = district_name.lower()
        index_labels[normalized_name] = district_label
        index_labels[f"{normalized_name} district"] = f"مقاطعة {district_label}"

    return index_labels


def _load_secondary_region_translations(data: dict[str, str]) -> dict[str, str]:
    CENTRAL_AFRICAN_PREFECTURE = data.get("CENTRAL_AFRICAN_PREFECTURE", {})
    DJIBOUTI_REGION = data.get("DJIBOUTI_REGION", {})
    EGYPT_GOVERNORATE = data.get("EGYPT_GOVERNORATE", {})
    GUATEMALA_DEPARTMENT = data.get("GUATEMALA_DEPARTMENT", {})
    MONGOLIA_PROVINCE = data.get("MONGOLIA_PROVINCE", {})
    index_labels: dict[str, str] = {}

    for governorate_name, governorate_label in EGYPT_GOVERNORATE.items():
        normalized_name = governorate_name.lower()
        index_labels[normalized_name] = governorate_label
        index_labels[f"{normalized_name} governorate"] = f"محافظة {governorate_label}"

    for region_name, region_label in DJIBOUTI_REGION.items():
        normalized_name = region_name.lower()
        index_labels[normalized_name] = region_label
        index_labels[f"{normalized_name} region"] = f"منطقة {region_label}"

    for department_name, department_label in GUATEMALA_DEPARTMENT.items():
        normalized_name = department_name.lower()
        index_labels[normalized_name] = department_label
        index_labels[f"{normalized_name} department"] = f"إدارة {department_label}"

    for province_name, province_label in MONGOLIA_PROVINCE.items():
        normalized_name = province_name.lower()
        index_labels[normalized_name] = province_label
        index_labels[f"{normalized_name} province"] = f"محافظة {province_label}"

    for prefecture_name, prefecture_label in CENTRAL_AFRICAN_PREFECTURE.items():
        normalized_name = prefecture_name.lower()
        index_labels[normalized_name] = prefecture_label
        index_labels[f"{normalized_name} prefecture"] = f"محافظة {prefecture_label}"

    return index_labels


data = open_json_file("geography/regions2.json") or {}
SECONDARY_REGION_TRANSLATIONS = _load_secondary_region_translations(data)
INDIA_REGION_TRANSLATIONS = _load_india_region_translations()

__all__ = [
    "SECONDARY_REGION_TRANSLATIONS",
    "INDIA_REGION_TRANSLATIONS",
]

len_print.data_len(
    "regions2.py",
    {
        "SECONDARY_REGION_TRANSLATIONS": SECONDARY_REGION_TRANSLATIONS,
        "INDIA_REGION_TRANSLATIONS": INDIA_REGION_TRANSLATIONS,
    },
)



"""
Public interface for the :mod:`make_bots.o_bots` package.

"""

from __future__ import annotations

from .parties_bot import get_parties_lab
from .peoples_resolver import make_people_lab, work_peoples
from .univer import te_universities

__all__ = [
    "get_by_label",
    "get_parties_lab",
    "make_by_label",
    "make_people_lab",
    "te_universities",
    "work_peoples",
]



"""
"Category:Defunct Canadian football teams": "تصنيف:فرق كرة قدم كندية سابقة",
"Category:LGBTQ players of Canadian football": "تصنيف:لاعبو كرة قدم كندية مثليون",
"""
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:African-American coaches of Canadian football": "تصنيف:مدربو كرة قدم كندية أمريكيون أفارقة",
    "Category:American players of Canadian football by populated place": "تصنيف:لاعبو كرة قدم كندية أمريكيون حسب المكان المأهول",
    "Category:American players of Canadian football by state": "تصنيف:لاعبو كرة قدم كندية أمريكيون حسب الولاية",
    "Category:American players of Canadian football": "تصنيف:لاعبو كرة قدم كندية أمريكيون",
    "Category:Australian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية أستراليون",
    "Category:Bahamian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية بهاميون",
    "Category:Cameroonian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كاميرونيون",
    "Category:Canadian football venues": "تصنيف:ملاعب كرة قدم كندية",
    "Category:Canadian football templates": "تصنيف:قوالب كرة قدم كندية",
    "Category:Canadian players of Canadian football by populated place": "تصنيف:لاعبو كرة قدم كندية كنديون حسب المكان المأهول",
    "Category:Coaches of Canadian football": "تصنيف:مدربو كرة قدم كندية",
    "Category:Cuban players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كوبيون",
    "Category:Democratic Republic of the Congo players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كونغويون ديمقراطيون",
    "Category:Dominican Republic players of Canadian football": "تصنيف:لاعبو كرة قدم كندية دومينيكانيون",
    "Category:English players of Canadian football": "تصنيف:لاعبو كرة قدم كندية إنجليز",
    "Category:Guyanese players of Canadian football": "تصنيف:لاعبو كرة قدم كندية غيانيون",
    "Category:Honduran players of Canadian football": "تصنيف:لاعبو كرة قدم كندية هندوراسيون",
    "Category:Jamaican players of Canadian football": "تصنيف:لاعبو كرة قدم كندية جامايكيون",
    "Category:Lebanese players of Canadian football": "تصنيف:لاعبو كرة قدم كندية لبنانيون",
    "Category:Nigerian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية نيجيريون",
    "Category:Panamanian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية بنميون",
    "Category:Players of Canadian football by nationality": "تصنيف:لاعبو كرة قدم كندية حسب الجنسية",
    "Category:Players of Canadian football by position": "تصنيف:لاعبو كرة قدم كندية حسب المركز",
    "Category:Players of Canadian football from Alabama": "تصنيف:لاعبو كرة قدم كندية من ألاباما",
    "Category:Players of Canadian football from Alaska": "تصنيف:لاعبو كرة قدم كندية من ألاسكا",
    "Category:Players of Canadian football from Alberta": "تصنيف:لاعبو كرة قدم كندية من ألبرتا",
    "Category:Players of Canadian football from Arizona": "تصنيف:لاعبو كرة قدم كندية من أريزونا",
    "Category:Players of Canadian football from Arkansas": "تصنيف:لاعبو كرة قدم كندية من أركنساس",
    "Category:Players of Canadian football from Atlanta": "تصنيف:لاعبو كرة قدم كندية من أتلانتا (جورجيا)",
    "Category:Players of Canadian football from Baltimore": "تصنيف:لاعبو كرة قدم كندية من بالتيمور",
    "Category:Players of Canadian football from Birmingham, Alabama": "تصنيف:لاعبو كرة قدم كندية من برمنغهام (ألاباما)",
    "Category:Players of Canadian football from Brampton": "تصنيف:لاعبو كرة قدم كندية من برامبتون (أونتاريو)",
    "Category:Players of Canadian football from British Columbia": "تصنيف:لاعبو كرة قدم كندية من كولومبيا البريطانية",
    "Category:Players of Canadian football from Brooklyn": "تصنيف:لاعبو كرة قدم كندية من بروكلين",
    "Category:Players of Canadian football from California": "تصنيف:لاعبو كرة قدم كندية من كاليفورنيا",
    "Category:Players of Canadian football from Chicago": "تصنيف:لاعبو كرة قدم كندية من شيكاغو",
    "Category:Players of Canadian football from Cincinnati": "تصنيف:لاعبو كرة قدم كندية من سينسيناتي",
    "Category:Players of Canadian football from Cleveland": "تصنيف:لاعبو كرة قدم كندية من كليفلاند",
    "Category:Players of Canadian football from Colorado": "تصنيف:لاعبو كرة قدم كندية من كولورادو",
    "Category:Players of Canadian football from Columbia, South Carolina": "تصنيف:لاعبو كرة قدم كندية من كولومبيا (كارولاينا الجنوبية)",
    "Category:Players of Canadian football from Columbus, Ohio": "تصنيف:لاعبو كرة قدم كندية من كولومبوس (أوهايو)",
    "Category:Players of Canadian football from Connecticut": "تصنيف:لاعبو كرة قدم كندية من كونيتيكت",
    "Category:Players of Canadian football from Dallas": "تصنيف:لاعبو كرة قدم كندية من دالاس",
    "Category:Players of Canadian football from Dayton, Ohio": "تصنيف:لاعبو كرة قدم كندية من دايتون (أوهايو)",
    "Category:Players of Canadian football from Delaware": "تصنيف:لاعبو كرة قدم كندية من ديلاوير",
    "Category:Players of Canadian football from Denver": "تصنيف:لاعبو كرة قدم كندية من دنفر (كولورادو)",
    "Category:Players of Canadian football from Detroit": "تصنيف:لاعبو كرة قدم كندية من ديترويت",
    "Category:Players of Canadian football from Florida": "تصنيف:لاعبو كرة قدم كندية من فلوريدا",
    "Category:Players of Canadian football from Fort Lauderdale, Florida": "تصنيف:لاعبو كرة قدم كندية من فورت لاودردال (فلوريدا)",
    "Category:Players of Canadian football from Georgia (U.S. state)": "تصنيف:لاعبو كرة قدم كندية من ولاية جورجيا",
    "Category:Players of Canadian football from Hawaii": "تصنيف:لاعبو كرة قدم كندية من هاواي",
    "Category:Players of Canadian football from Honolulu": "تصنيف:لاعبو كرة قدم كندية من هونولولو",
    "Category:Players of Canadian football from Houston": "تصنيف:لاعبو كرة قدم كندية من هيوستن",
    "Category:Players of Canadian football from Idaho": "تصنيف:لاعبو كرة قدم كندية من أيداهو",
    "Category:Players of Canadian football from Illinois": "تصنيف:لاعبو كرة قدم كندية من إلينوي",
    "Category:Players of Canadian football from Indiana": "تصنيف:لاعبو كرة قدم كندية من إنديانا",
    "Category:Players of Canadian football from Indianapolis": "تصنيف:لاعبو كرة قدم كندية من إنديانابوليس",
    "Category:Players of Canadian football from Jackson, Mississippi": "تصنيف:لاعبو كرة قدم كندية من جاكسون (مسيسيبي)",
    "Category:Players of Canadian football from Jacksonville, Florida": "تصنيف:لاعبو كرة قدم كندية من جاكسونفيل (فلوريدا)",
    "Category:Players of Canadian football from Kansas City, Missouri": "تصنيف:لاعبو كرة قدم كندية من كانساس سيتي (ميزوري)",
    "Category:Players of Canadian football from Kansas": "تصنيف:لاعبو كرة قدم كندية من كانساس",
    "Category:Players of Canadian football from Kentucky": "تصنيف:لاعبو كرة قدم كندية من كنتاكي",
    "Category:Players of Canadian football from Kingston, Jamaica": "تصنيف:لاعبو كرة قدم كندية من كينغستون",
    "Category:Players of Canadian football from Lagos": "تصنيف:لاعبو كرة قدم كندية من ولاية لاغوس",
    "Category:Players of Canadian football from Las Vegas": "تصنيف:لاعبو كرة قدم كندية من لاس فيغاس (نيفادا)",
    "Category:Players of Canadian football from Long Beach, California": "تصنيف:لاعبو كرة قدم كندية من لونغ بيتش (كاليفورنيا)",
    "Category:Players of Canadian football from Los Angeles": "تصنيف:لاعبو كرة قدم كندية من لوس أنجلوس",
    "Category:Players of Canadian football from Louisiana": "تصنيف:لاعبو كرة قدم كندية من لويزيانا",
    "Category:Players of Canadian football from Louisville, Kentucky": "تصنيف:لاعبو كرة قدم كندية من لويفيل (كنتاكي)",
    "Category:Players of Canadian football from Manitoba": "تصنيف:لاعبو كرة قدم كندية من مانيتوبا",
    "Category:Players of Canadian football from Maryland": "تصنيف:لاعبو كرة قدم كندية من ماريلند",
    "Category:Players of Canadian football from Massachusetts": "تصنيف:لاعبو كرة قدم كندية من ماساتشوستس",
    "Category:Players of Canadian football from Memphis, Tennessee": "تصنيف:لاعبو كرة قدم كندية من ممفيس (تينيسي)",
    "Category:Players of Canadian football from Miami": "تصنيف:لاعبو كرة قدم كندية من ميامي",
    "Category:Players of Canadian football from Michigan": "تصنيف:لاعبو كرة قدم كندية من ميشيغان",
    "Category:Players of Canadian football from Minneapolis": "تصنيف:لاعبو كرة قدم كندية من مينيابوليس",
    "Category:Players of Canadian football from Minnesota": "تصنيف:لاعبو كرة قدم كندية من منيسوتا",
    "Category:Players of Canadian football from Mississippi": "تصنيف:لاعبو كرة قدم كندية من مسيسيبي",
    "Category:Players of Canadian football from Missouri": "تصنيف:لاعبو كرة قدم كندية من ميزوري",
    "Category:Players of Canadian football from Montana": "تصنيف:لاعبو كرة قدم كندية من مونتانا",
    "Category:Players of Canadian football from Nevada": "تصنيف:لاعبو كرة قدم كندية من نيفادا",
    "Category:Players of Canadian football from New Brunswick": "تصنيف:لاعبو كرة قدم كندية من نيو برونزويك",
    "Category:Players of Canadian football from New Jersey": "تصنيف:لاعبو كرة قدم كندية من نيوجيرسي",
    "Category:Players of Canadian football from New Mexico": "تصنيف:لاعبو كرة قدم كندية من نيومكسيكو",
    "Category:Players of Canadian football from New Orleans": "تصنيف:لاعبو كرة قدم كندية من نيو أورلينز",
    "Category:Players of Canadian football from New York (state)": "تصنيف:لاعبو كرة قدم كندية من ولاية نيويورك",
    "Category:Players of Canadian football from New York City": "تصنيف:لاعبو كرة قدم كندية من مدينة نيويورك",
    "Category:Players of Canadian football from Newark, New Jersey": "تصنيف:لاعبو كرة قدم كندية من نيوآرك (نيو جيرسي)",
    "Category:Players of Canadian football from Norfolk, Virginia": "تصنيف:لاعبو كرة قدم كندية من نورفولك (فرجينيا)",
    "Category:Players of Canadian football from North Carolina": "تصنيف:لاعبو كرة قدم كندية من كارولاينا الشمالية",
    "Category:Players of Canadian football from North Dakota": "تصنيف:لاعبو كرة قدم كندية من داكوتا الشمالية",
    "Category:Players of Canadian football from Nova Scotia": "تصنيف:لاعبو كرة قدم كندية من نوفا سكوشا",
    "Category:Players of Canadian football from Oakland, California": "تصنيف:لاعبو كرة قدم كندية من أوكلاند (كاليفورنيا)",
    "Category:Players of Canadian football from Ohio": "تصنيف:لاعبو كرة قدم كندية من أوهايو",
    "Category:Players of Canadian football from Oklahoma City": "تصنيف:لاعبو كرة قدم كندية من أوكلاهوما سيتي",
    "Category:Players of Canadian football from Oklahoma": "تصنيف:لاعبو كرة قدم كندية من أوكلاهوما",
    "Category:Players of Canadian football from Ontario": "تصنيف:لاعبو كرة قدم كندية من أونتاريو",
    "Category:Players of Canadian football from Oregon": "تصنيف:لاعبو كرة قدم كندية من أوريغن",
    "Category:Players of Canadian football from Orlando, Florida": "تصنيف:لاعبو كرة قدم كندية من أورلاندو (فلوريدا)",
    "Category:Players of Canadian football from Pasadena, California": "تصنيف:لاعبو كرة قدم كندية من باسادينا (كاليفورنيا)",
    "Category:Players of Canadian football from Pennsylvania": "تصنيف:لاعبو كرة قدم كندية من بنسلفانيا",
    "Category:Players of Canadian football from Pensacola, Florida": "تصنيف:لاعبو كرة قدم كندية من بينساكولا (فلوريدا)",
    "Category:Players of Canadian football from Philadelphia": "تصنيف:لاعبو كرة قدم كندية من فيلادلفيا",
    "Category:Players of Canadian football from Phoenix, Arizona": "تصنيف:لاعبو كرة قدم كندية من فينيكس (أريزونا)",
    "Category:Players of Canadian football from Pittsburgh": "تصنيف:لاعبو كرة قدم كندية من بيتسبرغ",
    "Category:Players of Canadian football from Quebec": "تصنيف:لاعبو كرة قدم كندية من كيبك",
    "Category:Players of Canadian football from Queens, New York": "تصنيف:لاعبو كرة قدم كندية من كوينز (نيويورك)",
    "Category:Players of Canadian football from Sacramento, California": "تصنيف:لاعبو كرة قدم كندية من ساكرامنتو (كاليفورنيا)",
    "Category:Players of Canadian football from San Antonio": "تصنيف:لاعبو كرة قدم كندية من سان أنطونيو",
    "Category:Players of Canadian football from San Diego": "تصنيف:لاعبو كرة قدم كندية من سان دييغو",
    "Category:Players of Canadian football from San Francisco": "تصنيف:لاعبو كرة قدم كندية من سان فرانسيسكو",
    "Category:Players of Canadian football from San Jose, California": "تصنيف:لاعبو كرة قدم كندية من سان خوسيه (كاليفورنيا)",
    "Category:Players of Canadian football from Saskatchewan": "تصنيف:لاعبو كرة قدم كندية من ساسكاتشوان",
    "Category:Players of Canadian football from Seattle": "تصنيف:لاعبو كرة قدم كندية من سياتل",
    "Category:Players of Canadian football from South Carolina": "تصنيف:لاعبو كرة قدم كندية من كارولاينا الجنوبية",
    "Category:Players of Canadian football from St. Louis": "تصنيف:لاعبو كرة قدم كندية من سينت لويس",
    "Category:Players of Canadian football from St. Petersburg, Florida": "تصنيف:لاعبو كرة قدم كندية من سانت بيترسبرغ (فلوريدا)",
    "Category:Players of Canadian football from Stockton, California": "تصنيف:لاعبو كرة قدم كندية من ستوكتون (كاليفورنيا)",
    "Category:Players of Canadian football from Tampa, Florida": "تصنيف:لاعبو كرة قدم كندية من تامبا (فلوريدا)",
    "Category:Players of Canadian football from Tennessee": "تصنيف:لاعبو كرة قدم كندية من تينيسي",
    "Category:Players of Canadian football from Texas": "تصنيف:لاعبو كرة قدم كندية من تكساس",
    "Category:Players of Canadian football from Utah": "تصنيف:لاعبو كرة قدم كندية من يوتا",
    "Category:Players of Canadian football from Vermont": "تصنيف:لاعبو كرة قدم كندية من فيرمونت",
    "Category:Players of Canadian football from Virginia": "تصنيف:لاعبو كرة قدم كندية من فرجينيا",
    "Category:Players of Canadian football from Washington (state)": "تصنيف:لاعبو كرة قدم كندية من ولاية واشنطن",
    "Category:Players of Canadian football from Washington, D.C.": "تصنيف:لاعبو كرة قدم كندية من واشنطن العاصمة",
    "Category:Players of Canadian football from West Virginia": "تصنيف:لاعبو كرة قدم كندية من فرجينيا الغربية",
    "Category:Players of Canadian football from Wisconsin": "تصنيف:لاعبو كرة قدم كندية من ويسكونسن",
    "Category:Players of Canadian football from Wyoming": "تصنيف:لاعبو كرة قدم كندية من وايومنغ",
    "Category:Players of Canadian football": "تصنيف:لاعبو كرة قدم كندية",
    "Category:Puerto Rican players of Canadian football": "تصنيف:لاعبو كرة قدم كندية بورتوريكيون",
    "Category:Samoan players of Canadian football": "تصنيف:لاعبو كرة قدم كندية سامويون",
    "Category:Sierra Leonean players of Canadian football": "تصنيف:لاعبو كرة قدم كندية سيراليونيون",
    "Category:Venezuelan players of Canadian football": "تصنيف:لاعبو كرة قدم كندية فنزويليون",
}

data2 = {
    "Category:Canadian football media": "تصنيف:إعلام كرة قدم كندية",
    "Category:Canadian football people from Calgary": "تصنيف:أعلام كرة قدم كندية من كالغاري",
    "Category:Canadian football people from Edmonton": "تصنيف:أعلام كرة قدم كندية من إدمونتون",
    "Category:Canadian football people from Greater Sudbury": "تصنيف:أعلام كرة قدم كندية من غريتر سودبوري",
    "Category:Canadian football people from Halifax, Nova Scotia": "تصنيف:أعلام كرة قدم كندية من هاليفاكس (نوفا سكوشيا)",
    "Category:Canadian football people from Hamilton, Ontario": "تصنيف:أعلام كرة قدم كندية من هاميلتون",
    "Category:Canadian football people from London, Ontario": "تصنيف:أعلام كرة قدم كندية من لندن (أونتاريو)",
    "Category:Canadian football people from Mississauga": "تصنيف:أعلام كرة قدم كندية من ميسيسوجا",
    "Category:Canadian football people from Montreal": "تصنيف:أعلام كرة قدم كندية من مونتريال",
    "Category:Canadian football people from New Westminster": "تصنيف:أعلام كرة قدم كندية من نيو ويستمينيستر (كولومبيا البريطانية)",
    "Category:Canadian football people from Ottawa": "تصنيف:أعلام كرة قدم كندية من أوتاوا",
    "Category:Canadian football people from Quebec City": "تصنيف:أعلام كرة قدم كندية من مدينة كيبك",
    "Category:Canadian football people from Regina, Saskatchewan": "تصنيف:أعلام كرة قدم كندية من ريجاينا",
    "Category:Canadian football people from Saskatoon": "تصنيف:أعلام كرة قدم كندية من ساسكاتون",
    "Category:Canadian football people from Toronto": "تصنيف:أعلام كرة قدم كندية من تورونتو",
    "Category:Canadian football people from Vancouver": "تصنيف:أعلام كرة قدم كندية من فانكوفر",
    "Category:Canadian football people from Victoria, British Columbia": "تصنيف:أعلام كرة قدم كندية من فيكتوريا (كولومبيا البريطانية)",
    "Category:Canadian football people from Windsor, Ontario": "تصنيف:أعلام كرة قدم كندية من وندسور (أونتاريو)",
    "Category:Canadian football people from Winnipeg": "تصنيف:أعلام كرة قدم كندية من وينيبيغ",
    "Category:Canadian football terminology": "تصنيف:مصطلحات كرة قدم كندية",
}

data3 = {
    "Category:Canadian football by city": "تصنيف:كرة القدم الكندية حسب المدينة",
    "Category:Canadian football by country": "تصنيف:كرة القدم الكندية حسب البلد",
    "Category:Canadian football by province or territory": "تصنيف:كرة القدم الكندية حسب المقاطعة أو الإقليم",
    "Category:Canadian football in Alberta": "تصنيف:كرة القدم الكندية في ألبرتا",
    "Category:Canadian football in British Columbia": "تصنيف:كرة القدم الكندية في كولومبيا البريطانية",
    "Category:Canadian football in Calgary": "تصنيف:كرة القدم الكندية في كالغاري",
    "Category:Canadian football in Canada by city": "تصنيف:كرة القدم الكندية في كندا حسب المدينة",
    "Category:Canadian football in Canada": "تصنيف:كرة القدم الكندية في كندا",
    "Category:Canadian football in Edmonton": "تصنيف:كرة القدم الكندية في إدمونتون",
    "Category:Canadian football in Hamilton, Ontario": "تصنيف:كرة القدم الكندية في هاميلتون",
    "Category:Canadian football in Manitoba": "تصنيف:كرة القدم الكندية في مانيتوبا",
    "Category:Canadian football in Montreal": "تصنيف:كرة القدم الكندية في مونتريال",
    "Category:Canadian football in Nova Scotia": "تصنيف:كرة القدم الكندية في نوفا سكوشا",
    "Category:Canadian football in Ontario": "تصنيف:كرة القدم الكندية في أونتاريو",
    "Category:Canadian football in Ottawa": "تصنيف:كرة القدم الكندية في أوتاوا",
    "Category:Canadian football in Quebec": "تصنيف:كرة القدم الكندية في كيبك",
    "Category:Canadian football in Saskatchewan": "تصنيف:كرة القدم الكندية في ساسكاتشوان",
    "Category:Canadian football in Toronto": "تصنيف:كرة القدم الكندية في تورونتو",
    "Category:Canadian football in Vancouver": "تصنيف:كرة القدم الكندية في فانكوفر",
    "Category:Canadian football in Winnipeg": "تصنيف:كرة القدم الكندية في وينيبيغ",
    "Category:Canadian football teams by city": "تصنيف:فرق كرة القدم الكندية حسب المدينة",
    "Category:Canadian football teams by league": "تصنيف:فرق كرة القدم الكندية حسب الدوري",
    "Category:Canadian football teams by province or territory": "تصنيف:فرق كرة القدم الكندية حسب المقاطعة أو الإقليم",
    "Category:Canadian football teams in Alberta": "تصنيف:فرق كرة القدم الكندية في ألبرتا",
    "Category:Canadian football teams in Calgary": "تصنيف:فرق كرة القدم الكندية في كالغاري",
    "Category:Canadian football teams in Edmonton": "تصنيف:فرق كرة القدم الكندية في إدمونتون",
    "Category:Canadian football teams in Manitoba": "تصنيف:فرق كرة القدم الكندية في مانيتوبا",
    "Category:Canadian football teams in Ontario": "تصنيف:فرق كرة القدم الكندية في أونتاريو",
    "Category:Canadian football teams in Ottawa": "تصنيف:فرق كرة القدم الكندية في أوتاوا",
    "Category:Canadian football teams in Saskatchewan": "تصنيف:فرق كرة القدم الكندية في ساسكاتشوان",
    "Category:Canadian football teams in Toronto": "تصنيف:فرق كرة القدم الكندية في تورونتو",
    "Category:Canadian football teams in Vancouver": "تصنيف:فرق كرة القدم الكندية في فانكوفر",
    "Category:Canadian football teams in Winnipeg": "تصنيف:فرق كرة القدم الكندية في وينيبيغ",
    "Category:Canadian football venues in British Columbia": "تصنيف:ملاعب كرة القدم الكندية في كولومبيا البريطانية",
    "Category:Canadian football venues in Manitoba": "تصنيف:ملاعب كرة القدم الكندية في مانيتوبا",
    "Category:Canadian football venues in Ontario": "تصنيف:ملاعب كرة القدم الكندية في أونتاريو",
    "Category:Canadian football venues in Quebec": "تصنيف:ملاعب كرة القدم الكندية في كيبك",
    "Category:Canadian football venues in the United States": "تصنيف:ملاعب كرة القدم الكندية في الولايات المتحدة",
    "Category:Canadian football": "تصنيف:كرة القدم الكندية",
    "Category:Canadian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كنديون",
    "Category:Canadian football running backs": "تصنيف:راكضون للخلف كرة قدم كندية",
    "Category:Canadian football linebackers": "تصنيف:أظهرة كرة قدم كندية",
    "Category:Canadian football centres": "تصنيف:لاعبو وسط كرة قدم كندية",
    "Category:Canadian football defensive linemen": "تصنيف:مدافعو خط كرة قدم كندية",
    "Category:Canadian football defensive backs": "تصنيف:مدافعون خلفيون كرة قدم كندية",
    "Category:Canadian football fullbacks": "تصنيف:مدافعو كرة قدم كندية",
    "Category:Canadian football placekickers": "تصنيف:مسددو كرة قدم كندية",
    "Category:Canadian football scouts": "تصنيف:كشافة كرة قدم كندية",
    "Category:Canadian football offensive linemen": "تصنيف:مهاجمو خط كرة قدم كندية",
    "Category:Canadian football tackles": "تصنيف:مصطدمو كرة قدم كندية",
    "Category:Canadian football wide receivers": "تصنيف:مستقبلون واسعون كرة قدم كندية",
    "Category:Canadian football guards": "تصنيف:حراس كرة قدم كندية",
    "Category:Canadian football quarterbacks": "تصنيف:أظهرة رباعيون كرة قدم كندية",
}

to_test = [
    ("test_canadian_football_1", data1),
    ("test_canadian_football_2", data2),
    ("test_canadian_football_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_canadian_football_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_canadian_football_2(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_canadian_football_3(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    # dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
""" """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.countries_names_and_sports import (
    resolve_countries_names_sport_with_ends,
)
from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2
from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import wrap_team_xo_normal_2025_with_ends
from ArWikiCats.new_resolvers.sports_resolvers.sport_lab_nat import sport_lab_nat_load_new

sport_lab2_test_data = {
    "defunct indoor boxing": "بوكسينغ داخل الصالات سابقة",
    "defunct indoor boxing clubs": "أندية بوكسينغ داخل الصالات سابقة",
    "defunct indoor boxing cups": "كؤوس بوكسينغ داخل الصالات سابقة",
    "defunct football cup competitions": "منافسات كؤوس كرة قدم سابقة",
    "defunct football cups": "كؤوس كرة قدم سابقة",
    "professional football cups": "كؤوس كرة قدم للمحترفين",
    "domestic football cup": "كؤوس كرة قدم محلية",
    "domestic football cups": "كؤوس كرة قدم محلية",
    "football cup competitions": "منافسات كؤوس كرة قدم",
    "football cups": "كؤوس كرة قدم",
    "basketball cup competitions": "منافسات كؤوس كرة سلة",
    "field hockey cup competitions": "منافسات كؤوس هوكي ميدان",
    "baseball world cup": "كأس العالم لكرة القاعدة",
    "biathlon world cup": "كأس العالم للبياثلون",
    "cricket world cup": "كأس العالم للكريكت",
    "curling world cup": "كأس العالم للكيرلنغ",
    "esports world cup": "كأس العالم للرياضة الإلكترونية",
    "hockey world cup": "كأس العالم للهوكي",
    "men's hockey world cup": "كأس العالم للهوكي للرجال",
    "men's rugby world cup": "كأس العالم للرجبي للرجال",
    "men's softball world cup": "كأس العالم للكرة اللينة للرجال",
    "netball world cup": "كأس العالم لكرة الشبكة",
    "rugby league world cup": "كأس العالم لدوري الرجبي",
    "rugby world cup": "كأس العالم للرجبي",
    "wheelchair rugby league world cup": "كأس العالم لدوري الرجبي على الكراسي المتحركة",
    "wheelchair rugby world cup": "كأس العالم للرجبي على الكراسي المتحركة",
    "women's cricket world cup ": "كأس العالم للكريكت للسيدات",
    "women's cricket world cup tournaments": "بطولات كأس العالم للكريكت للسيدات",
    "women's cricket world cup": "كأس العالم للكريكت للسيدات",
    "women's field hockey world cup": "كأس العالم لهوكي الميدان للسيدات",
    "women's hockey world cup": "كأس العالم للهوكي للسيدات",
    "women's rugby league world cup": "كأس العالم لدوري الرجبي للسيدات",
    "women's rugby world cup": "كأس العالم للرجبي للسيدات",
    "women's softball world cup": "كأس العالم للكرة اللينة للسيدات",
    "wrestling world cup": "كأس العالم للمصارعة",
}

nats_sport_multi_v2_data = {
    "yemeni mens basketball cup": "كأس اليمن لكرة السلة للرجال",
    "yemeni womens basketball cup": "كأس اليمن لكرة السلة للسيدات",
    "yemeni basketball cup": "كأس اليمن لكرة السلة",
    "yemeni defunct basketball cup": "كؤوس كرة سلة يمنية سابقة",
    "chinese domestic boxing cup": "كؤوس بوكسينغ صينية محلية",
    "chinese boxing cup": "كأس الصين للبوكسينغ",
    "chinese boxing cup competitions": "منافسات كأس الصين للبوكسينغ",
    "chinese defunct boxing cup competitions": "منافسات كؤوس بوكسينغ صينية سابقة",
    "chinese defunct indoor boxing cups": "كؤوس بوكسينغ صينية داخل الصالات سابقة",
    "chinese defunct boxing cups": "كؤوس بوكسينغ صينية سابقة",
    "chinese defunct outdoor boxing cups": "كؤوس بوكسينغ صينية في الهواء الطلق سابقة",
    "chinese professional boxing cups": "كؤوس بوكسينغ صينية للمحترفين",
    "chinese indoor boxing cups": "كؤوس بوكسينغ صينية داخل الصالات",
    "chinese outdoor boxing cups": "كؤوس بوكسينغ صينية في الهواء الطلق",
    "chinese domestic boxing cups": "كؤوس بوكسينغ صينية محلية",
    "chinese domestic women's boxing cups": "كؤوس بوكسينغ صينية محلية للسيدات",
    "chinese boxing cups": "كؤوس بوكسينغ صينية",
}

sport_lab_nat_load_new_data = {
    "asian domestic football cups": "كؤوس كرة قدم آسيوية محلية",
    "austrian football cups": "كؤوس كرة قدم نمساوية",
    "belgian football cups": "كؤوس كرة قدم بلجيكية",
    "dutch football cups": "كؤوس كرة قدم هولندية",
    "english football cups": "كؤوس كرة قدم إنجليزية",
    "european domestic football cups": "كؤوس كرة قدم أوروبية محلية",
    "german football cups": "كؤوس كرة قدم ألمانية",
    "irish football cups": "كؤوس كرة قدم أيرلندية",
    "italian football cups": "كؤوس كرة قدم إيطالية",
    "north american domestic football cups": "كؤوس كرة قدم أمريكية شمالية محلية",
    "oceanian domestic football cups": "كؤوس كرة قدم أوقيانوسية محلية",
    "republic-of ireland football cups": "كؤوس كرة قدم أيرلندية",
    "scottish football cups": "كؤوس كرة قدم إسكتلندية",
    "spanish basketball cups": "كؤوس كرة سلة إسبانية",
    "spanish football cups": "كؤوس كرة قدم إسبانية",
    "thai football cups": "كؤوس كرة قدم تايلندية",
    "welsh football cups": "كؤوس كرة قدم ويلزية",
}

rcn_sport_with_ends_data = {
    "new zealand amateur kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للهواة",
    "new zealand youth kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للشباب",
    "new zealand men's kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للرجال",
    "new zealand women's kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للسيدات",
    "new zealand kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ",
    "yemen amateur kick boxing cup": "كأس اليمن للكيك بوكسينغ للهواة",
    "yemen youth kick boxing cup": "كأس اليمن للكيك بوكسينغ للشباب",
    "yemen men's kick boxing cup": "كأس اليمن للكيك بوكسينغ للرجال",
    "yemen women's kick boxing cup": "كأس اليمن للكيك بوكسينغ للسيدات",
    "yemen kick boxing cup": "كأس اليمن للكيك بوكسينغ",
}

to_test = [
    ("test_sport_lab2_data", sport_lab2_test_data, wrap_team_xo_normal_2025_with_ends),
    ("test_resolve_nats_sport_multi_v2", nats_sport_multi_v2_data, resolve_nats_sport_multi_v2),
    ("test_sport_lab_nat_load_new", sport_lab_nat_load_new_data, sport_lab_nat_load_new),
    ("test_rcn_sport_with_ends", rcn_sport_with_ends_data, resolve_countries_names_sport_with_ends),
    # ---
    ("test_test_sport_cup_1", sport_lab2_test_data, resolve_nats_sport_multi_v2),
    ("test_test_sport_cup_2", sport_lab2_test_data, sport_lab_nat_load_new),
    ("test_test_sport_cup_3", sport_lab2_test_data, resolve_countries_names_sport_with_ends),
    # ---
]


@pytest.mark.parametrize("category, expected", nats_sport_multi_v2_data.items(), ids=nats_sport_multi_v2_data.keys())
@pytest.mark.skip2
def test_resolve_nats_sport_multi_v2(category: str, expected: str) -> None:
    label1 = resolve_nats_sport_multi_v2(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", sport_lab2_test_data.items(), ids=sport_lab2_test_data.keys())
@pytest.mark.skip2
def test_sport_lab2_data(category: str, expected: str) -> None:
    label1 = wrap_team_xo_normal_2025_with_ends(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize(
    "category, expected", sport_lab_nat_load_new_data.items(), ids=sport_lab_nat_load_new_data.keys()
)
@pytest.mark.skip2
def test_sport_lab_nat_load_new(category: str, expected: str) -> None:
    label1 = sport_lab_nat_load_new(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", rcn_sport_with_ends_data.items(), ids=rcn_sport_with_ends_data.keys())
@pytest.mark.skip2
def test_rcn_sport_with_ends(category: str, expected: str) -> None:
    label1 = resolve_countries_names_sport_with_ends(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.skip2
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    # dump_diff(add_result, f"{name}_add")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Population and people helpers."""

from __future__ import annotations

import functools
import re

from ...helps import logger
from ...translations import People_key, film_key_women_2, nats_to_add
from ..matables_bots.bot import Pp_Priffix
from .utils import resolve_suffix_template


def work_peoples_old(name: str) -> str:
    """Return the label for ``name`` based on the population prefixes table.

    Args:
        name: The category name that may contain a known population suffix.

    Returns:
        The resolved Arabic label or an empty string when no mapping exists.
    """
    logger.info(f"<<lightpurple>> >work_peoples:> len People_key: {len(People_key)} ")
    PpP_lab = ""
    person = ""
    pri = ""
    for pri_ff in Pp_Priffix:
        if not person:
            if name.endswith(pri_ff):
                logger.info(f'>>>><<lightblue>> work_peoples :"{name}"')
                pri = pri_ff
                person = name[: -len(pri_ff)]
                break

    personlab = People_key.get(person, "")
    if not personlab:
        logger.info(f'>>>><<lightblue>> cant find personlab for:"{person}"')

    if person and personlab:
        logger.info(f">>>><<lightblue>> {person=}, {personlab=}")
        PpP_lab = Pp_Priffix[pri].format(personlab)
        logger.info(f'>>>><<lightblue>> name.endswith pri("{pri}"), {PpP_lab=}')
    return PpP_lab


@functools.lru_cache(maxsize=None)
def work_peoples(name: str) -> str:
    """Return the label for ``name`` based on the population prefixes table.

    Args:
        name: The category name that may contain a known population suffix.

    Returns:
        The resolved Arabic label or an empty string when no mapping exists.
    """

    logger.info(f"<<lightpurple>> work_peoples lookup for '{name}'")

    def _lookup(prefix: str) -> str:
        """Fetch a people label using the given prefix key."""
        return People_key.get(prefix, "")

    label = resolve_suffix_template(name, Pp_Priffix, _lookup)
    if label:
        logger.debug(f"Resolved work_peoples: {name=}, {label=}")
    else:
        logger.debug(f"Failed to resolve work_peoples: {name=}")
    return label


def make_people_lab(normalized_value: str) -> str:
    """Return a label for general ``people`` categories.

    Args:
        value: Category type describing a people group.

    Returns:
        The formatted Arabic label or an empty string if the value is not
        recognised.
    """

    normalized_value = normalized_value.strip()

    new_label = nats_to_add.get(normalized_value, "")

    if not new_label:
        base_value = re.sub(r"people$", "", normalized_value)
        film_label = film_key_women_2.get(base_value, "")
        if film_label:
            new_label = f"أعلام {film_label}"

    if new_label:
        logger.debug(">>>>>>>>>>>>")
        logger.debug(f">> make_people_lab {normalized_value=}, {new_label=}")

    return new_label


__all__ = [
    "work_peoples",
    "make_people_lab",
]



"""Tests for :mod:`make_bots.o_bots.bys`."""

from __future__ import annotations

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.o_bots.bys import get_by_label

data_0 = {
    "12th iranian majlis": "المجلس الإيراني الثاني عشر",
    "13th iranian majlis": "المجلس الإيراني الثالث عشر",
    "15th iranian majlis": "المجلس الإيراني الخامس عشر",
    "1866 asian winter games": "الألعاب الآسيوية الشتوية 1866",
    "1866 european games": "الألعاب الأوروبية 1866",
    "1866 indian general election": "الانتخابات العامة الهندية 1866",
    "1866 pan american games": "دورة الألعاب الأمريكية 1866",
    "1866 parapan american games": "ألعاب بارابان الأمريكية 1866",
    "1866 presidential candidates": "مرشحون رئاسيون 1866",
    "1866 sea games": "ألعاب البحر 1866",
    "1866 summer olympics": "الألعاب الأولمبية الصيفية 1866",
    "1866 summer paralympics": "الألعاب البارالمبية الصيفية 1866",
    "1866 united states elections": "انتخابات الولايات المتحدة 1866",
    "1866 united states": "الولايات المتحدة 1866",
    "war in iraq (1866–1866)": "الحرب في العراق (1866–1866)",
    "united kingdom (1866–1866)": "المملكة المتحدة (1866–1866)",
    "uefa euro 1866": "بطولة أمم أوروبا 1866",
    "second polish republic (1866–1866)": "الجمهورية البولندية الثانية (1866–1866)",
    "british columbia (1866–1866)": "كولومبيا البريطانية (1866–1866)",
}

by_label_data = {
    "africa by country": "إفريقيا حسب البلد",
    "alaska by populated place": "ألاسكا حسب المكان المأهول",
    "alberta by city": "ألبرتا حسب المدينة",
    "antarctica by country": "القارة القطبية الجنوبية حسب البلد",
    "asia by country": "آسيا حسب البلد",
    "asia by region": "آسيا حسب المنطقة",
    "australia by city": "أستراليا حسب المدينة",
    "australia by populated place": "أستراليا حسب المكان المأهول",
    "australia by state or territory": "أستراليا حسب الولاية أو الإقليم",
    "austria by city": "النمسا حسب المدينة",
    "belgium by region": "بلجيكا حسب المنطقة",
    "brazil by state": "البرازيل حسب الولاية",
    "budapest by line": "بودابست حسب الخط",
    "canada by province or territory": "كندا حسب المقاطعة أو الإقليم",
    "caribbean by country": "الكاريبي حسب البلد",
    "caribbean by dependent territory": "الكاريبي حسب الأقاليم التابعة",
    "china by city": "الصين حسب المدينة",
    "costa rica by firing squad": "كوستاريكا رميا بالرصاص",
    "czech republic by city": "التشيك حسب المدينة",
    "drug offenses by nationality": "جرائم المخدرات حسب الجنسية",
    "europe by country": "أوروبا حسب البلد",
    "illinois by populated place": "إلينوي حسب المكان المأهول",
    "india by state or union territory": "الهند حسب الولاية أو الإقليم الاتحادي",
    "ivory coast by subject": "ساحل العاج حسب الموضوع",
    "netherlands by city": "هولندا حسب المدينة",
    "netherlands by province": "هولندا حسب المقاطعة",
    "non-profit organizations by country": "منظمات غير ربحية حسب البلد",
    "north america by country": "أمريكا الشمالية حسب البلد",
    "oceania by country": "أوقيانوسيا حسب البلد",
    "peru by province": "بيرو حسب المقاطعة",
    "philippines by architectural style": "الفلبين حسب الطراز المعماري",
    "philippines by region": "الفلبين حسب المنطقة",
    "philippines by type": "الفلبين حسب الفئة",
    "politics by state": "سياسة حسب الولاية",
    "republic-of ireland by year": "جمهورية أيرلندا حسب السنة",
    "russia by city": "روسيا حسب المدينة",
    "slovenia by populated place": "سلوفينيا حسب المكان المأهول",
    "south africa by city": "جنوب إفريقيا حسب المدينة",
    "south america by country": "أمريكا الجنوبية حسب البلد",
    "soviet union by war": "الاتحاد السوفيتي حسب الحرب",
    "spain by autonomous community": "إسبانيا حسب الحكم الذاتي",
    "spain by populated place": "إسبانيا حسب المكان المأهول",
    "spain by year": "إسبانيا حسب السنة",
    "sri lanka by city": "سريلانكا حسب المدينة",
    "summer olympics by year": "الألعاب الأولمبية الصيفية حسب السنة",
    "sweden by diocese": "السويد حسب الأبرشية",
    "sweden by populated place": "السويد حسب المكان المأهول",
    "turkey by province": "تركيا حسب المقاطعة",
    "ukraine by firing squad": "أوكرانيا رميا بالرصاص",
    "ukraine by region": "أوكرانيا حسب المنطقة",
    "united kingdom by city": "المملكة المتحدة حسب المدينة",
    "united states by architectural style": "الولايات المتحدة حسب الطراز المعماري",
    "united states by century": "الولايات المتحدة حسب القرن",
    "united states by city": "الولايات المتحدة حسب المدينة",
    "united states by county": "الولايات المتحدة حسب المقاطعة",
    "united states by decade": "الولايات المتحدة حسب العقد",
    "united states by industry": "الولايات المتحدة حسب الصناعة",
    "united states by issue": "الولايات المتحدة حسب القضية",
    "united states by populated place": "الولايات المتحدة حسب المكان المأهول",
    "united states by school": "الولايات المتحدة حسب المدرسة",
    "united states by state or region": "الولايات المتحدة حسب الولاية أو المنطقة",
    "united states by state or territory": "الولايات المتحدة حسب الولاية أو الإقليم",
    "united states by state": "الولايات المتحدة حسب الولاية",
    "united states by team": "الولايات المتحدة حسب الفريق",
    "united states by time": "الولايات المتحدة حسب الوقت",
    "united states by year": "الولايات المتحدة حسب السنة",
    "utah by firing squad": "يوتا رميا بالرصاص",
    "western sahara by subject": "الصحراء الغربية حسب الموضوع",
    "winter olympics by year": "الألعاب الأولمبية الشتوية حسب السنة",
    "world-war-ii by nationality": "الحرب العالمية الثانية حسب الجنسية",
}

to_test = [
    ("test_get_by_label", by_label_data, get_by_label),
]


@pytest.mark.parametrize("category, expected", by_label_data.items(), ids=by_label_data.keys())
@pytest.mark.fast
def test_get_by_label(category: str, expected: str) -> None:
    label = get_by_label(category)
    assert label == expected, f"Failed for category: {category}"


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.skip2
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest

from ArWikiCats import resolve_arabic_category_label

data = {
    # "Category:History of the Royal Air Force": "تصنيف:تاريخ القوات الجوية الملكية",
    # "Category:History of the Royal Navy": "تصنيف:تاريخ البحرية الملكية",
    "Category:Afghan criminal law": "تصنيف:القانون الجنائي الأفغاني",
    "Category:Archaeology of Europe by period": "تصنيف:علم الآثار في أوروبا حسب الحقبة",
    "Category:Award winners by nationality": "تصنيف:حائزو جوائز حسب الجنسية",
    "Category:Government of Saint Barthélemy": "تصنيف:حكومة سان بارتيلمي",
    "Category:Historical novels": "تصنيف:روايات تاريخية",
    "Category:Historical poems": "تصنيف:قصائد تاريخية",
    "Category:Historical short stories": "تصنيف:قصص قصيرة تاريخية",
    # "Category:History of the British Army": "تصنيف:تاريخ الجيش البريطاني",
    "Category:History of the British National Party": "تصنيف:تاريخ الحزب الوطني البريطاني",
    "Category:Military alliances involving Japan": "تصنيف:تحالفات عسكرية تشمل اليابان",
    "Category:Military alliances involving Yemen": "تصنيف:تحالفات عسكرية تشمل اليمن",
    "Category:Penal system in Afghanistan": "تصنيف:قانون العقوبات في أفغانستان",
    "Category:Prehistory of Venezuela": "تصنيف:فنزويلا ما قبل التاريخ",
    "Category:American award winners": "تصنيف:حائزو جوائز أمريكيون",
    "Category:Treaties extended to Curaçao": "تصنيف:اتفاقيات امتدت إلى كوراساو",
}


@pytest.mark.parametrize("category, expected", data.items(), ids=data.keys())
@pytest.mark.fast
def test_politics_and_history(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected



#
from __future__ import annotations

from dataclasses import dataclass, field
from typing import Dict, Iterable, List

from .helps import logger
from .main_processers.main_resolve import CategoryResult, resolve_label

LABEL_PREFIX = "تصنيف:"


@dataclass
class ProcessedCategory:
    """Data structure representing each processed category."""

    original: str
    normalized: str
    raw_label: str
    final_label: str
    has_label: bool


@dataclass
class EventProcessingResult:
    """Structured results for a batch."""

    processed: List[ProcessedCategory] = field(default_factory=list)
    labels: Dict[str, str] = field(default_factory=dict)
    no_labels: List[str] = field(default_factory=list)
    category_patterns: int = 0


class EventProcessor:
    """Fast, pure processing engine for categories."""

    def __init__(self) -> None:
        """Create a processor with a placeholder for future configuration."""
        self.config = None

    @staticmethod
    def _normalize_category(category: str) -> str:
        """Normalize the input category string quickly."""
        if category.startswith("\ufeff"):
            category = category[1:]
        return category.replace("_", " ")

    @staticmethod
    def _prefix_label(raw_label: str) -> str:
        """Add prefix only when needed."""
        if not raw_label:
            return ""

        stripped = raw_label.strip()
        if not stripped or stripped == LABEL_PREFIX:
            return ""

        if stripped.startswith(LABEL_PREFIX):
            return stripped

        return f"{LABEL_PREFIX}{raw_label}"

    def process(self, categories: Iterable[str]) -> EventProcessingResult:
        """Process a batch of categories."""
        result = EventProcessingResult()

        for original in categories:
            if not original:
                continue

            normalized = self._normalize_category(original)

            raw_label: CategoryResult = resolve_label(normalized)

            final_label = self._prefix_label(raw_label.ar)
            has_label = bool(final_label)

            if has_label:
                result.labels[normalized] = final_label
                if raw_label.from_match:
                    result.category_patterns += 1
            else:
                result.no_labels.append(normalized)

            result.processed.append(
                ProcessedCategory(
                    original=original,
                    normalized=normalized,
                    raw_label=raw_label.ar,
                    final_label=final_label,
                    has_label=has_label,
                )
            )

        return result

    def process_single(self, category: str) -> ProcessedCategory:
        """Process a single category and return the detailed record."""
        processed = self.process([category]).processed
        if not processed:
            return ProcessedCategory(category, category, "", "", False)
        return processed[0]


def _get_processed_category(category_r: str) -> ProcessedCategory:
    """Helper to process a single category with a default processor."""
    processor = EventProcessor()
    return processor.process_single(category_r)


def resolve_arabic_category_label(category_r: str) -> str:
    """Return final AR label with prefix."""
    return _get_processed_category(category_r).final_label


def batch_resolve_labels(
    new_list: List[str],
) -> EventProcessingResult:
    """Run the event processor on the given list of categories."""
    processor = EventProcessor()
    result = processor.process(new_list)

    return result



"""
Tests
"""

import pytest

from ArWikiCats.time_resolvers.time_to_arabic import convert_time_to_arabic


def test_make_year_lab() -> None:
    # Test basic year
    result = convert_time_to_arabic("2020")
    assert isinstance(result, str)
    assert "2020" in result or result == ""  # May return empty for invalid cases
    assert result == "2020"

    # Test year with BC
    result_bc = convert_time_to_arabic("500 bc")
    assert isinstance(result_bc, str)
    assert result_bc == "500 ق م"

    # Test year with BCE
    result_bce = convert_time_to_arabic("300 bce")
    assert isinstance(result_bce, str)
    assert result_bce == "300 ق م"

    # Test century
    result_century = convert_time_to_arabic("21st century")
    assert isinstance(result_century, str)
    assert result_century == "القرن 21"

    # Test millennium
    result_millennium = convert_time_to_arabic("3rd millennium")
    assert isinstance(result_millennium, str)
    assert result_millennium == "الألفية 3"

    # Test with month
    result_with_month = convert_time_to_arabic("january 2020")
    assert isinstance(result_with_month, str)
    assert result_with_month == "يناير 2020"


def test_make_month_lab() -> None:
    # Test with numeric year
    result = convert_time_to_arabic("2020")
    assert result == "2020"

    # Test with month and year
    result_month = convert_time_to_arabic("january 2020")
    assert isinstance(result_month, str)
    assert result_month == "يناير 2020"

    # Test with empty string
    result_empty = convert_time_to_arabic("")
    assert isinstance(result_empty, str)
    assert result_empty == ""

    # Test with just letters
    result_letters = convert_time_to_arabic("january")
    assert isinstance(result_letters, str)
    assert result_letters == "يناير"


class TestMakeYearLabBasicPatterns:
    @pytest.mark.parametrize(
        "year, expected",
        [
            # Pure numeric AD year
            ("1990", "1990"),
            ("42", "42"),
            # Pure numeric BC/BCE years
            ("1990 bc", "1990 ق م"),
            ("42 bce", "42 ق م"),
            # Decades (AD)
            ("10s", "عقد 10"),
            ("1990s", "عقد 1990"),
            # Decades (BC/BCE)
            ("10s bc", "عقد 10 ق م"),
            ("1990s bce", "عقد 1990 ق م"),
            # Centuries (AD)
            ("21st century", "القرن 21"),
            ("3rd century", "القرن 3"),
            # Centuries (BC/BCE)
            ("21st century bc", "القرن 21 ق م"),
            ("3rd century bce", "القرن 3 ق م"),
            # Millennia (AD)
            ("2nd millennium", "الألفية 2"),
            ("1st millennium", "الألفية 1"),
            # Millennia (BC/BCE)
            ("2nd millennium bce", "الألفية 2 ق م"),
            ("1st millennium bc", "الألفية 1 ق م"),
        ],
    )
    def test_year_lab_core_cases(self, year: str, expected: str) -> None:
        # We ignore leading/trailing whitespace differences by stripping.
        assert convert_time_to_arabic(year) == expected


class TestMakeYearLabMonths:
    @pytest.mark.parametrize(
        "year, expected",
        [
            # Month + year (lowercase)
            ("january 1990", "يناير 1990"),
            ("march 2001", "مارس 2001"),
            # Month + year (mixed case)
            ("January 1990", "يناير 1990"),
            ("DecemBer 2010", "ديسمبر 2010"),
            # Month + year + BC/BCE
            ("january 1990 bc", "يناير 1990 ق م"),
            ("march 10 bce", "مارس 10 ق م"),
            # Bare month names
            ("january", "يناير"),
            ("January", "يناير"),
            ("march", "مارس"),
        ],
    )
    def test_year_lab_month_cases(self, year: str, expected: str) -> None:
        result = convert_time_to_arabic(year)
        # Strip to normalize trailing space after month name / suffix.
        assert result == expected


class TestMakeYearLabRangesAndSpecial:
    @pytest.mark.parametrize(
        "year, expected",
        [
            # Numeric ranges should be preserved as-is
            ("1990-1999", "1990-1999"),
            ("1990–1999", "1990–1999"),  # en dash
            ("1990−1999", "1990−1999"),  # minus sign
        ],
    )
    def test_year_lab_ranges_and_allowed_suffixes(self, year: str, expected: str) -> None:
        assert convert_time_to_arabic(year) == expected

    @pytest.mark.parametrize(
        "year",
        [
            # Completely unrelated text
            "random text",
            "not a year",
            # Contains English letters and is not recognized
            "year 1990",
        ],
    )
    def test_year_lab_unmatched_inputs_return_empty(self, year: str) -> None:
        assert convert_time_to_arabic(year) == ""


class TestMakeMonthLabBasic:
    @pytest.mark.parametrize(
        "year, expected",
        [
            # Pure numeric years: returned unchanged (trimmed)
            ("1990", "1990"),
            (" 1990 ", "1990"),
            ("42", "42"),
        ],
    )
    def test_month_lab_numeric_only(self, year: str, expected: str) -> None:
        assert convert_time_to_arabic(year) == expected

    @pytest.mark.parametrize(
        "year, expected",
        [
            # Month + year (lowercase)
            ("january 1990", "يناير 1990"),
            ("march 2001", "مارس 2001"),
            # Month + year (mixed case)
            ("January 1990", "يناير 1990"),
            ("DecemBer 2010", "ديسمبر 2010"),
            # Bare month names
            ("january", "يناير"),
            ("January", "يناير"),
            ("march", "مارس"),
            # Decade-like expressions are not handled here
            ("10s", "عقد 10"),
            ("10s bc", "عقد 10 ق م"),
            ("january 1990 bc", "يناير 1990 ق م"),
            ("march 10 bce", "مارس 10 ق م"),
        ],
    )
    def test_month_lab_with_month_names(self, year: str, expected: str) -> None:
        result = convert_time_to_arabic(year)
        # Normalize trailing spaces for bare months.
        assert result == expected


class TestMakeMonthLabRangesAndSpecial:
    @pytest.mark.parametrize(
        "year, expected",
        [
            # Numeric ranges preserved as-is
            ("1990-1999", "1990-1999"),
            ("1990–1999", "1990–1999"),
            ("1990−1999", "1990−1999"),
        ],
    )
    def test_month_lab_ranges_and_allowed_suffixes(self, year: str, expected: str) -> None:
        assert convert_time_to_arabic(year) == expected

    @pytest.mark.parametrize(
        "year",
        [
            # Arbitrary strings
            "random text",
            "year 1990",
            "A",
        ],
    )
    def test_month_lab_unmatched_inputs_return_empty(self, year: str) -> None:
        assert convert_time_to_arabic(year) == ""



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

for_countries_t = {
    # "Category:Winter Olympics competitors for Algeria by sport": "تصنيف:منافسون في الألعاب الأولمبية الشتوية من الجزائر حسب الرياضة",
    # "Category:Winter Olympics competitors for Algeria by sport": "تصنيف:منافسون أولمبيون شتويون من الجزائر حسب الرياضة",
    "Category:Winter Olympics competitors for Eswatini": "تصنيف:منافسون أولمبيون شتويون من إسواتيني",
    "Category:Winter Olympics competitors by country": "تصنيف:منافسون أولمبيون شتويون حسب البلد",
    "Category:Winter Olympics competitors by sport": "تصنيف:منافسون أولمبيون شتويون حسب الرياضة",
    "Category:Winter Olympics competitors by sport and country": "تصنيف:منافسون أولمبيون شتويون حسب الرياضة والبلد",
    "Category:Winter Olympics competitors by sport and year": "تصنيف:منافسون أولمبيون شتويون حسب الرياضة والسنة",
    "Category:Winter Olympics competitors by year": "تصنيف:منافسون أولمبيون شتويون حسب السنة",
}


@pytest.mark.parametrize("category, expected", for_countries_t.items(), ids=for_countries_t.keys())
@pytest.mark.fast
def test_for_countries_t(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_for_countries_t", for_countries_t, resolve_arabic_category_label),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests for :mod:`make_bots.o_bots.army`.
"""

from __future__ import annotations

import pytest

from ArWikiCats.new_resolvers.nationalities_resolvers.nationalities_v2 import resolve_by_nats

test_army_nat_data_1 = {
    "albanian congress": "الكونغرس الألباني",
    "argentine army personnel": "أفراد الجيش الأرجنتيني",
    "australian army personnel": "أفراد الجيش الأسترالي",
    "australian courts": "محاكم أسترالية",
    "australian senate elections": "انتخابات مجلس الشيوخ الأسترالي",
    "austrian parliament": "البرلمان النمساوي",
    "bahraini second division": "الدوري البحريني الدرجة الثانية",
    "bangladesh army generals": "جنرالات الجيش البنغلاديشي",
    "belgian army personnel": "أفراد الجيش البلجيكي",
    "belgian second division": "الدوري البلجيكي الدرجة الثانية",
    "brazilian air force generals": "جنرالات القوات الجوية البرازيلية",
    "british army personnel": "أفراد الجيش البريطاني",
    "canadian air force generals": "جنرالات القوات الجوية الكندية",
    "canadian army personnel": "أفراد الجيش الكندي",
    "canadian coast guard": "خفر السواحل الكندي",
    "canadian congress": "الكونغرس الكندي",
    "canadian federal legislation": "تشريعات فيدرالية كندية",
    "canadian house-of-commons": "مجلس العموم الكندي",
    "canadian parliament": "البرلمان الكندي",
    "central american parliament": "البرلمان الأمريكي الأوسطي",
    "czech senate election": "انتخابات مجلس الشيوخ التشيكي",
    "dutch senate elections": "انتخابات مجلس الشيوخ الهولندي",
    "european parliament": "البرلمان الأوروبي",
    "libyan second division": "الدوري الليبي الدرجة الثانية",
    "nigerian senate elections": "انتخابات مجلس الشيوخ النيجيري",
    "chilean air force generals": "جنرالات القوات الجوية التشيلية",
    "chilean army personnel": "أفراد الجيش التشيلي",
    "scottish parliament": "البرلمان الإسكتلندي",
}

test_army_nat_data_2 = {
    "egyptian army personnel": "أفراد الجيش المصري",
    "french air force generals": "جنرالات القوات الجوية الفرنسية",
    "german federal legislation": "تشريعات فيدرالية ألمانية",
    "indian parliament": "البرلمان الهندي",
    "irish senate elections": "انتخابات مجلس الشيوخ الأيرلندي",
    "italian army personnel": "أفراد الجيش الإيطالي",
    "japanese parliament": "البرلمان الياباني",
    "kenyan second division": "الدوري الكيني الدرجة الثانية",
    "mexican congress": "الكونغرس المكسيكي",
    "moroccan army personnel": "أفراد الجيش المغربي",
    "norwegian parliament": "البرلمان النرويجي",
    "pakistani army generals": "جنرالات الجيش الباكستاني",
    "polish air force generals": "جنرالات القوات الجوية البولندية",
    "portuguese senate elections": "انتخابات مجلس الشيوخ البرتغالي",
    "russian army personnel": "أفراد الجيش الروسي",
    "saudi coast guard": "خفر السواحل السعودي",
    "spanish parliament": "البرلمان الإسباني",
    "swedish army personnel": "أفراد الجيش السويدي",
    "turkish air force generals": "جنرالات القوات الجوية التركية",
    "yemeni army personnel": "أفراد الجيش اليمني",
}


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", test_army_nat_data_1.items(), ids=test_army_nat_data_1.keys())
def test_army_nat_1(category: str, expected: str) -> None:
    result = resolve_by_nats(category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", test_army_nat_data_2.items(), ids=test_army_nat_data_2.keys())
def test_army_nat_2(category: str, expected: str) -> None:
    result = resolve_by_nats(category)
    assert result == expected



#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

data0 = {
    "yemeni major indoor wheelchair football league": "الدوري الرئيسي اليمني لكرة القدم على الكراسي المتحركة داخل الصالات",
}

data1 = {
    "australian rugby union": "اتحاد الرجبي الأسترالي",
    "australian women's ice hockey league": "الدوري الأسترالي لهوكي الجليد للسيدات",
    "british rugby union": "اتحاد الرجبي البريطاني",
    "egyptian league": "الدوري المصري",
    "english football league": "الدوري الإنجليزي لكرة القدم",
    "english rugby league": "الدوري الإنجليزي للرجبي",
    "french rugby league": "الدوري الفرنسي للرجبي",
    "french rugby union": "اتحاد الرجبي الفرنسي",
    "hong kong fa cup": "كأس الاتحاد الهونغ الكونغي",
    "indian federation cup": "كأس الاتحاد الهندي",
    "italian rugby union": "اتحاد الرجبي الإيطالي",
    "lebanese federation cup": "كأس الاتحاد اللبناني",
    "north american hockey league": "الدوري الأمريكي الشمالي للهوكي",
    "north american soccer league": "الدوري الأمريكي الشمالي لكرة القدم",
    "oceanian rugby union": "اتحاد الرجبي الأوقيانوسي",
    "russian rugby union": "اتحاد الرجبي الروسي",
    "south american rugby union": "اتحاد الرجبي الأمريكي الجنوبي",
    "welsh rugby league": "الدوري الويلزي للرجبي",
}

data_2 = {
    "argentine grand prix": "جائزة الأرجنتين الكبرى",
    "british open": "المملكة المتحدة المفتوحة",
    "croatian ice hockey league": "الدوري الكرواتي لهوكي الجليد",
    "eritrean premier league": "الدوري الإريتري الممتاز",
    "french rugby union leagues": "اتحاد دوري الرجبي الفرنسي",
    "irish league": "الدوري الأيرلندي",
    "saudi super cup": "كأس السوبر السعودي",
}

data_3 = {}

data_4 = {}

to_test = [
    ("test_mans_data_0", data0, resolve_label_ar),
    ("test_mans_data_1", data1, resolve_nats_sport_multi_v2),
    ("test_mans_data_3", data_3, resolve_nats_sport_multi_v2),
    ("test_mans_data_4", data_4, resolve_nats_sport_multi_v2),
]


@pytest.mark.parametrize("category, expected", data0.items(), ids=data0.keys())
def test_mans_data_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_mans_data_1(category: str, expected: str) -> None:
    assert resolve_nats_sport_multi_v2(category) == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
def test_mans_data_3(category: str, expected: str) -> None:
    assert resolve_nats_sport_multi_v2(category) == expected


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # dump_diff_text (expected, diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
